Tento text byl publikován jako součást knihy (Lopatková et al., 2016) vydané nakladatelstvím Karolinum.

# Gramatická komponenta

# Gramatikalizované alternace

V následujících kapitolách uvádíme pravidla popisující změny ve valenční struktuře sloves v příznakových konstrukcích diatezí, reflexivity a reciprocity stručně popsané v odd. THEORY > 2.1. Tato pravidla, která se typicky omezují na změny v morfematické formě zasažených doplnění, se uplatňují na valenční rámce lexikálních jednotek uvedené v datové komponentě slovníku VALLEX, v nichž jsou zachyceny morfematické formy valenčních doplnění odpovídající tzv. nepříznakovému užití lexikálních jednotek, tj. aktivní, nereciproční a nereflexivní konstrukci. Daná pravidla umožňují odvodit morfematická vyjádření valenčních doplnění charakteristická pro příznaková užití lexikálních jednotek sloves (zde též označovaná jako tzv. odvozené valenční rámce).

Při formalizaci pravidel pro odvození morfematických forem valenčních doplnění v příznakových konstrukcích jsme se inspirovali přístupem Pajase a Urešové (Pajas, 2005; Urešová – Pajas, 2009; Urešová, 2011), od kterých přebíráme základní strukturu pravidel. Pravidla zde uváděná se skládají z podmínky a seznamu změn, které je nutné v rámci provést; pokud se změny vztahují na valenční doplnění s odlišnými funktory, jsou v nich tato doplnění zastoupena proměnnými – tento přístup umožňuje redukci celkového počtu pravidel a větší míru generalizace. Navíc rozlišujeme mezi pravidly základními (často jde o jediné pravidlo pro daný typ diateze, reciprocity nebo reflexivity) a mezi pravidly doplňkovými (ta zachycují ty aspekty tvoření příznakových konstrukcí, které jsou charakteristické pro jednotlivé syntaktické třídy sloves).

Podrobnější údaje k formátu pravidel uvádíme v úvodu kapitoly 1 Diateze, kapitoly 2 Syntaktická reflexivita a kapitoly 3 Reciprocita.

# 1 Diateze

Diateze představují centrální typ gramatikalizovaných alternací, jsou podmíněny užitím specifického morfologického významu slovesa a jsou obvykle spojeny s odsunutím Konatele (ACT) z prominentní syntaktické pozice subjektu. V datové komponentě slovníku je možnost tvořit příznakové konstrukce jednotlivých typů diatezí vyznačena v atributu diat.

Pravidla umožňující z nepříznakového valenčního rámce, zachyceného v datové komponentě slovníku, odvodit valenční rámec popisující příznakové konstrukce diatezí 1-1 mají následující strukturu:

Typ diateze | Pravidlo
Charakteristika pravidla | Název pravidla
podmínky | diat: Hodnota atributu diat Podmínky na valenční rámec
slovesná forma | Specifikace morfologického tvaru slovesa v příznakovém členu diateze
shoda | Specifikace tvaru slovesa na základě shody
FUNKTOR | Změny morfematických forem u valenčního doplnění s daným funktorem
obligatornost | Valenční doplnění, která se v příznakovém členu diateze mění na obligatorní (případně jsou jako obligatorní do odvozeného valenčního rámce doplněna)1-2

Při formulaci jednotlivých pravidel používáme následující značení:

Podmínky na uplatnění pravidla
Příslušné pravidlo pro odvození valenčních rámců pro příznakové konstrukce diatezí se může uplatnit jen na valenční rámce lexikálních jednotek s atributem diat nesoucím příslušnou hodnotu (tedy pass, deagent, poss nebo recipient), a to pokud splňují v pravidle specifikované podmínky na valenční rámec.

X a Y: Proměnné pro funktory
Symboly X a Y užívané v pravidlech představují proměnné, které zastupují valenční doplnění s různými funktory. Pokud chceme omezit množinu funktorů, které mohou být hodnotou dané proměnné, píšeme např. Y[PAT|ADDR] (Y je buď Patiens, nebo Adresát).
Proměnná X má výsadní postavení; používáme ji pro to valenční doplnění, které se v příznakové konstrukci dostává do subjektové pozice.

Yi, ¬Yi: Podmínky na valenční doplnění
K diatezím se vztahují podmínky specifikující morfematickou formu valenčního doplnění, jehož přítomnost v rámci je pro uplatnění daného pravidla požadována či takové uplatnění naopak blokuje (symbol ¬); např. podmínka "Y4" požaduje přítomnost valenčního doplnění, které umožňuje realizaci akuzativem (bez ohledu na další možné formy), podmínka "¬Y2, 4" zakazuje přítomnost doplnění, které by připouštělo realizaci genitivem nebo realizaci akuzativem (či oběma formami).

i → j, ✱, ∅: Změny morfematických forem
Uvedené symboly užíváme při popisu změn morfematických forem valenčních doplnění. Tyto změny jsou zapsány ve formátu "seznam forem doplnění v nepříznakové konstrukci → seznam forem doplnění v příznakové konstrukci", např. "4 → 1" označuje, že doplnění uvedené v rámci jako akuzativní se v příznakové konstrukci mění na nominativní.
Pokud se mají nahradit všechny formy, kterými může být v nepříznakové konstrukci dané doplnění realizováno, používáme na levé straně pravidla symbol ✱.
Symbol ∅ vyskytující se na pravé straně pravidel označuje, že příslušné valenční doplnění nemůže být v příznakové konstrukci v povrchověsyntaktické struktuře vyjádřeno.

se → ∅, si → ∅, se, si → ∅: Změny v reflexivitě slovesného tvaru
Uvedené symboly užíváme pro odstranění reflexiva se, si, a to v případě, kdy se daná gramatikalizovaná alternace uplatňuje u slovesa s reflexivním lemmatem, ale buď je sloveso ve výsledné konstrukci nereflexivní, např. u pasivizace modlit seimpf → být modlen, srov. začal […] modlitbu, která kdy na zemi byla modlena, nebo je třeba zabránit dvojí reflexivizaci, např. u deagentizace cenitI (si)impf → cení se, srov. menší rané brambory se cení pro vyšší stolní hodnotu.

## 1.1 Pasivní a rezultativní diateze s pomocným slovesem být (rezultativ prostý)

V datové komponentě slovníku je možnost tvořit příznakové konstrukce pasivní diateze vyznačena u příslušných lexikálních jednotek sloves hodnotou atributu diat: pass; implicitně je touto hodnotou zachycena též možnost vytvářet příznakové struktury rezultativní diateze prosté.

Pro odvození valenčního rámce pro příznakové užití slovesa je nutno na valenční rámec odpovídající nepříznakovému členu diateze zachycený v datové komponentě aplikovat vždy:

- nejprve základní pravidlo pass_basic (pravidlo G1, odd. 1.1.1); toto pravidlo zachycuje změny v morfologickém tvaru slovesa, jeho shodu a dále změnu morfematického vyjádření ACT;

- a poté (v závislosti na podmínkách kladených na podobu valenčního rámce) právě jedno z doplňkových pravidel uvedených v odd. 1.1.2.

Některá slovesa charakterizuje více možností, jak syntakticky strukturovat příznakové členy pasivní či rezultativní prosté diateze. V takovém případě (nepříznakový) valenční rámec splňuje podmínky pro uplatnění více doplňkových pravidel; pro odvození všech přípustných valenčních rámců pro příznakové užití slovesa se pak aplikují všechny přípustné dvojice základní pravidlo – doplňkové pravidlo.

### 1.1.1 Základní pravidlo

Následující pravidlo zachycuje změny společné všem lexikálním jednotkám sloves, které vytvářejí příznakové konstrukce pasivní diateze a rezultativní prosté diateze.

Pasivní a rezultativní diateze | Pravidlo G1
Základní pravidlo (forma slovesa, shoda, změna formy Konatele) | pass_basic
podmínky | diat: pass ACT1
slovesná forma | → být + participium trpné, 1. pád1-3
shoda | participium trpné: číslo+rod, X být: číslo+rod+osoba, X
ACT | ✱ → 7, od+2

Slovesná forma:
Pravidlo G1, pass_basic, specifikuje, že slovesný tvar je tvořen pomocným slovesem být a 1. pádem participia trpného.1-4, 1-5

Proměnná X, shoda:
Proměnná X zde označuje – v souladu s výše uvedenou obecnou strukturou pravidel pro diateze, viz úvod kapitoly 1 – to valenční doplnění, které v příznakové konstrukci vstupuje do pozice subjektu (jedná se o doplnění, které je v aktivní konstrukci vyjádřeno akuzativem, příp. genitivem), a se kterým se tak v příznakové konstrukci shoduje složený slovesný tvar. Základní pravidlo takové doplnění blíže nespecifikuje, požadavky na jeho morfologické vlastnosti případně uvádějí až doplňková pravidla pro jednotlivé skupiny sloves (viz dále odd. 1.1.2).

Pokud valenční rámec slovesa doplnění s požadovanými morfologickými vlastnostmi neobsahuje nebo pokud je sice takové doplnění ve valenčním rámci identifikováno, v konkrétním užití je však toto doplnění vyjádřeno jinou možnou formou či má charakter (v povrchověsyntaktické struktuře nevyjádřeného) všeobecného aktantu, má složený slovesný tvar formu neutra singuláru, viz následující příklady (1)–(3).1-6

1. (1) bránitimpf ACT1 ADDR3 PATv+6, inf, aby MEANStyp7

   X neidentifikovánoKdo nechce za Ledčice hrát, není mu bráněno v odchodu.

   (sloveso nemá akuzativní ani genitivní doplnění, proměnná X tedy v příslušném doplňkovém pravidle G5, viz níže, nenabývá žádnou hodnotu a slovesný tvar je realizován jako neutrum singuláru)

2. (2) dokazovatimpf — dokázatIpf ACT1 PAT4, zda, že, cont ORIGoptna+6

   X=PATzda Zda Skopec skutečně muže zavraždil, bude muset být dokazováno podle nepřímých důkazů.

   (příslušné doplňkové pravidlo G2, viz níže, určuje X jako doplnění akuzativní, zde PAT, který je v této větě realizován závislou větou obsahovou uvozenou spojkou zda; slovesný tvar má proto shodu neutra singuláru)

3. (3) donášetimpf — donéstpf ACT1 ADDR3 PAT4, zda, že, cont

   X=PAT Doufejme ve zdravý rozum toho, kterému je donášeno.

   (příslušné doplňkové pravidlo G2, viz níže, určuje X jako doplnění akuzativní, zde PAT, ten však v této větě není v povrchověsyntaktické struktuře vyjádřen (jde o všeobecný aktant); slovesný tvar má proto shodu neutra singuláru)

Vyjádření ACT:
Vedle slovesného tvaru specifikuje základní pravidlo změny v morfematickém vyjádření Konatele (ACT). Ten je v případě pasivní diateze či rezultativní prosté diateze vyjádřen instrumentálem, předložkovým spojením od+2, nebo zůstává v povrchověsyntaktické struktuře nevyjádřen.

1. (4) hodnotitimpf ACT1 PAT4, inf, zda, že, cont EFFoptjako+4, na+4, jako+adj-4 MANNtyp MEANStyp7 CRITtyp

   ACT1 → 7 … pracovník je hodnocen podstatně větším počtem hodnotitelů než v případě grantové přihlášky.

2. (5) uvítatpf ACT1 PAT4, aby, že, cont MANNtyp

   ACT1 → od+2 … od našeho obchodnictva podnik tento bude s radostí uvítán…

### 1.1.2 Doplňková pravidla pro jednotlivé skupiny sloves

Pro derivaci valenčního rámce příznakového členu pasivní diateze a rezultativní prosté diateze je kromě základního pravidla nutné na valenční rámec odpovídající nepříznakovému užití uplatnit právě jedno doplňkové pravidlo; výběr tohoto pravidla je dán podobou daného valenčního rámce.

V následujících oddílech popisujeme pravidla pro tyto skupiny sloves:

- pravidla pro tranzitivní slovesa, odd. 1.1.2.1, a to:

  - pravidla pro slovesa s akuzativním doplněním, odd. 1.1.2.1a;

  - pravidla pro slovesa s genitivním doplněním (s obdobným chováním jako slovesa s akuzativem), odd. 1.1.2.1b;

  - pravidla pro slovesa s doplněním v genitivu kolísající mezi chováním typickým pro tranzitiva a chováním typickým pro intranzitiva, odd. 1.1.2.1c;

- pravidla pro intranzitivní slovesa, odd. 1.1.2.2, a to:

  - pravidla pro slovesa s doplněním v genitivu, odd. 1.1.2.2a;

  - pravidla pro slovesa bez doplnění v genitivu, odd. 1.1.2.2b.

#### 1.1.2.1 Slovesa tranzitivní (a slovesa s obdobným syntaktickým chováním)

Nejběžnějším typem slovesa, které vstupuje do pasivní či rezultativní prosté diateze, je sloveso tranzitivní. Označení tranzitivní sloveso zde užíváme v tradičním slova smyslu jako sloveso s akuzativním doplněním (odd. 1.1.2.1a). Jsme si ovšem vědomi toho, že tranzitivita jako syntaktická kategorie nebyla pro češtinu dosud uspokojivě vymezena (Hopper – Thompson, 1980). Lexikografické zpracování ukazuje, že některá slovesa s genitivním doplněním vykazují – vzhledem k pasivní a rezultativní prosté diatezi – stejné syntaktické chování jako slovesa s doplněním akuzativním či kolísají mezi chováním typickým pro slovesa s akuzativním doplněním a chováním typickým pro slovesa s jinými formami doplnění; taková slovesa řadíme též do tohoto oddílu (odd. 1.1.2.1b a odd. 1.1.2.1c).

##### 1.1.2.1a Slovesa s akuzativním doplněním.

Pro tato slovesa se po aplikaci základního pravidla pass_basic, viz pravidlo G1, uplatní následující pravidlo G2, pass_trans_acc:

Pasivní a rezultativní diateze | Pravidlo G2
Doplňkové pravidlo pro tranzitivní slovesa (se změnou 4 → 1) | pass_trans_acc
podmínky | diat: pass X4
slovesná forma | se, si → ∅
X | 4 → 1
Y | jako+4 → jako+1
| jako+adj-4 → jako+adj-1
| adj-4 → adj-1

Proměnná X, shoda:
Proměnná X zde označuje jakékoli valenční doplnění, jež může být v nepříznakovém členu diateze realizováno akuzativem (nejčastěji PAT, řidčeji EFF nebo ADDR, výjimečně také EXT).1-7 Podle výše uvedeného pravidla G1, pass_basic, se participium shoduje s tímto doplněním v rodě a čísle, pomocné sloveso být navíc i v osobě.

Morfematické vyjádření akuzativního valenčního doplnění X se mění na nominativní; má-li navíc X možnost vyjádření i jinou formou, tato forma se nemění.

1. (6) vrhatimpf — vrhnoutpf ACT1 PAT4, 7 DIR3 DIRtyp

   X=PAT4 → 1 Kostky byly vrženy.

   X=PAT7 → 7 Nikdo v celých Rybářích a v Karlových Varech nevěděl o tom, že bylo vrženo kamenem.

2. (7) doplňovatimpf — doplnitpf ACT1 PATk+3 EFF4, že, cont

   X=EFF4 → 1 Tento cíl byl doplněn k seznamu původních pěti cílů regionální politiky…

   X=EFFže → že Novelou bylo doplněno, že jediný společník nemůže žádat soud o zrušení své účasti ve společnosti.

3. (8) informovatbiasp ACT1 ADDR4 PATo+6

   X=ADDR4 → 1 Protože o výzkumu zbraní a o jejich použití nebývá široká veřejnost informována…

4. (9) ujítpf ACT1 EXT4

   X=EXT4 → 1 Z osady, ze které ráno odešli, bylo ujito přes deset kilometrů…

Proměnná Y:
V případě, že tranzitivní sloveso má doplnění odpovídající doplňku vyjádřenému morfematickými formami jako+4, jako+adj-4 nebo adj-4, je dané doplnění označeno proměnnou Y. V příznakovém členu pasivní diateze a rezultativní prosté diateze se morfematické vyjádření daného doplnění mění na nominativní; tak je zachována shoda s doplněním X, ke kterému se doplněk váže, viz následující příklady:

1. (10) cítitimpf ACT1 PAT4, že EFFjako+4, jako+adj-4

   Y=EFFjako+4 → jako+1 Rozdíl je to důležitý jenom pro specialistu, a tak jsou obvykle oba termíny cítěny jako synonyma.

2. (11) označovatimpf — označitpf ACT1 PAT4 EFFjako+4, za+4, jako+adj-4, za+adj-4 BENtyp3, pro+4

   Y=EFFjako+adj-4 → jako+adj-1 Výrobky, které trestuhodně plýtvají s odpadem, nemohou být označeny jako dobré.

3. (12) udržovatimpf — udržetpf ACT1 PAT4 EFFadj-4, adj-7

   Y=EFFadj-4 → adj-1 … a cesta […] byla naším špalírem udržována volná.

Reflexivní slovesa:
Pravidlo G2, pass_trans_acc, může být aplikováno i na reflexivní slovesa, v takovém případě je reflexivum se/si elidováno. Ve slovníku VALLEX je tento typ konstrukcí doložen u jediné lexikální jednotky s reflexivem se a dále u několika desítek lexikálních jednotek s reflexivem si:

1. (13) modlit seimpf ACT1 ADDRoptk+3 PATopt4 AIMtypza+4, aby

   se → ∅ Pán Ježíš jde spolu s učedníky do Getsemanské zahrady, […], aby začal nejbolestivější a nejštědřejší modlitbu, která kdy na zemi byla modlena.

2. (14) osvojovat siimpf — osvojit sipf ACT1 PAT4, zda, že, cont ORIGoptod+2, z+2 MANNtyp

   si → ∅ … učební zkušenosti jsou považovány výhradně za prostředky, s jejichž pomocí byly osvojeny určité vědomosti a dovednosti.

3. (15) oblibovat siimpf — oblíbit sipf ACT1 PAT4

   si → ∅ Spolupracovníky byl vážen, ctěn a oblíben.

Slovesa s akuzativním a genitivním doplněním:
A. Pravidlo G2, pass_trans_acc, se uplatňuje též u sloves, v jejichž rámci se vyskytují dvě různá doplnění, z nichž jedno umožňuje realizaci akuzativem a druhé genitivem; u takových sloves se genitivní doplnění do subjektové pozice v příznakové konstrukci přesunout nemůže:

1. (16) zprošťovatimpf — zprostitpf ACT1 ADDR4 PAT2

   X=ADDR4 → 1 … lidé, kteří stanou před soudem, bývají jen zřídkakdy zproštěni viny…

B. Také slovesa, u nichž genitiv alternuje s akuzativem jako morfematická forma téhož valenčního doplnění, tvoří pasivní a rezultativní prostou diatezi podle pravidla G2, pass_trans_acc; dochází u nich tedy ke změně X2, 4 → 2, 1, kdy se akuzativ mění na nominativ, zatímco ostatní formy (tj. genitiv, příp. další možné formy vyjádření) zůstávají zachovány:

1. (17) docilovatimpf — docílitpf ACT1 PAT2, 4, aby LOCtyp MEANStyp7

   X=PAT4 → 1 Tmavá střídka bývá často docílena vhodnými (povolenými) surovinami…

   X=PAT2 → 2 Právě použitím částečného sypání karamelového a pšeničného sladu bylo docíleno úplně nové chuťové varianty.

##### 1.1.2.1b Slovesa s doplněním v genitivu (s obdobným chováním jako slovesa s akuzativem).

Lexikografické zpracování sloves ukazuje, že některá reflexivní slovesa s genitivním doplněním vykazují v případě pasivní diateze a rezultativní prosté diateze obdobné syntaktické chování jako slovesa s doplněním akuzativním: v příznakových členech těchto diatezí dochází ke změně formy genitivního doplnění v nominativní, daným doplněním je tedy v příznakové konstrukci (stejně jako u sloves s doplněním akuzativním) zaplněna pozice subjektu.

Pravidlo G3, pass_trans_gen, lze dále uplatnit i na slovesa, která kolísají mezi chováním typickým pro tranzitiva a chováním typickým pro intranzitiva, viz následující odd. 1.1.2.1c.

Pasivní a rezultativní diateze | Pravidlo G3
Doplňkové pravidlo pro rámce s genitivem (se změnou 2 → 1) | pass_trans_gen
podmínky | diat: pass X2 & ¬Y4
slovesná forma | se, si → ∅
X | 2 → 1

1. (18) vážit siimpf ACT1 PAT2

   X=PAT2 → 1 Spolupracovníky byl vážen, ctěn a oblíben.

2. (19) dotýkat seimpf — dotknout sepf ACT1 PAT2

   X=PAT2 → 1 Je v ní dotčen problém, nakolik je člověk tvůrcem svých vlastních osudů…

   X=PAT2 → 1 Říká-li dnes ministr práce, že sociální dávky nejsou a nebudou krizí nijak dotčeny…

##### 1.1.2.1c 1.1.2.1c Slovesa s doplněním v genitivu kolísající mezi chováním typickým pro tranzitiva a chováním typickým pro intranzitiva.

Další skupinu sloves s genitivním doplněním charakterizuje kolísání mezi chováním typickým pro slovesa s akuzativním doplněním, kdy v případě pasivní diateze a rezultativní prosté diateze dochází ke změně formy genitivního doplnění v nominativní (dané doplnění pak zaplňuje pozici subjektu, pravidlo G3, pass_trans_gen, viz výše odd. 1.1.2.1b), a chováním typickým pro slovesa u nichž k takové změně nedochází (pravidlo G4, pass_intrans_gen, viz dále odd. 1.1.2.2a).

1. (20) dosahovatimpf — dosáhnoutpf ACT1 PAT2

   pravidlo G3, pass_trans_gen: X=PAT2 → 1 Vrchol byl dosažen 1. 4. 1999 v pozdních večerních hodinách všemi účastníky projektu.

   pravidlo G4, pass_intrans_gen: X=PAT2 → 2 … a vrcholu Sněžky bylo dosaženo v rekordním čase.

Reflexivní slovesa:
Reflexivum se/si u reflexivních sloves z této skupiny vykazuje obdobné kolísání: pokud je v příznakovém členu diateze genitiv nahrazen nominativem, je reflexivum elidováno v souladu s pravidlem G3, pass_trans_gen (viz výše); oproti tomu pokud je genitiv v příznakovém členu diateze zachován, zůstává zachováno i reflexivum se/si, jak odpovídá pravidlu G4, pass_intrans_gen (viz níže).

1. (21) domáhat seimpf — domoci sepf ACT1 PAT2 ORIGoptna+6, u+2 BENtyp3

   pravidlo G3, pass_trans_gen: se → ∅, X=PAT2 → 1 V případě, že zde byl případ, pro který writ nebyl ještě vytvořen, nemohlo být právo domoženo u soudu.

   pravidlo G4, pass_intrans_gen: se → se, Y=PAT2 → 2 Z české strany byla hájena jednota země a domáháno se plné jazykové rovnoprávnosti.

2. (22) povšimnout sipf ACT1 PAT2, jak, zda, že, cont

   pravidlo G3, pass_trans_gen: si → ∅, X=PAT2 → 1 Nemohla být nepovšimnuta totální nespolupráce na úrovni radnice.

   pravidlo G4, pass_intrans_gen: si → si, Y=PAT2 → 2 Pokud si jí bylo kdy povšimnuto…

Dodejme, že pouze na základě valenčního rámce a hodnoty atributu diat nelze rozhodnout, zda je možné na dané sloveso aplikovat pouze pravidlo G3, pass_trans_gen, pouze pravidlo G4, pass_intrans_gen, nebo obě tato pravidla. Jelikož informace o tom, které pravidlo je na dané sloveso třeba aplikovat, není v datové komponentě slovníku VALLEX v současné době uvedena, aplikujeme na všechna slovesa s genitivním doplněním obě pravidla, přestože se tak pro některá slovesa ve výsledném seznamu možných forem příznakového členu diateze mohou objevit i formy, které korpusový materiál nedokládá.

#### 1.1.2.2 Slovesa intranzitivní

Dalším typem sloves, která tvoří pasivní a rezultativní prostou diatezi, jsou slovesa intranzitivní, tedy slovesa bez akuzativního doplnění. 1-8 Chování těchto sloves popisují dvě pravidla: pravidlo G4, pass_intrans_gen, pro slovesa s genitivním doplněním (odd. 1.1.2.2a) a pravidlo G5, pass_intrans_no, pro slovesa bez genitivního doplnění (odd. 1.1.2.2b).

##### 1.1.2.2a 1.1.2.2a Intranzitivní slovesa s doplněním v genitivu.

Chování většiny intranzitivních sloves s genitivním doplněním popisuje doplňkové pravidlo G4, pass_intrans_gen. Tato slovesa v příznakových konstrukcích pasivní diateze a rezultativní prosté diateze nepřipouštějí změnu genitivního doplnění v nominativní: formy valenčních doplnění vyjma Konatele jsou tak totožné s formami v nepříznakovém členu diateze. Protože toto doplňkové pravidlo nestanovuje hodnotu proměnné X (viz odd. 1.1.1), má tvar slovesa v příznakových konstrukcích daných diatezí vždy formu neutra singuláru.

Pasivní a rezultativní diateze | Pravidlo G4
Doplňkové pravidlo pro rámce s genitivem (beze změny formy doplnění) | pass_intrans_gen
podmínky | diat: pass Y2 & ¬X4
pouze akce z pass_basic

1. (23) dbátimpf ACT1 PAT2, na+4

   Y=PAT2 Varovných hlasů podnikatelů nebylo dbáno.

Reflexivní slovesa:
U intranzitivních reflexivních sloves dochází v příznakovém členu pasivní a rezultativní prosté diateze k zachování reflexiva se/si (viz též příklady (21)–(22)):

1. (24) dopouštětI seimpf — dopustitI sepf ACT1 ADDRoptna+6 PAT2

   Y=PAT2 Je to starý, těžce udržovatelný produkt, u kterého bychom museli zdolat všechny hříchy, kterých se v něm bylo dopuštěno.

##### 1.1.2.2b 1.1.2.2b Intranzitivní slovesa bez doplnění v genitivu.

Nereflexivní slovesa a reflexiva tantum, u nichž ani jedno doplnění nemůže být realizováno akuzativem ani genitivem, 1-9 tvoří pasivní a rezultativní prostou diatezi podle následujícího pravidla G5, pass_intrans_no:

Pasivní a rezultativní diateze | Pravidlo G5
Doplňkové pravidlo pro slovesa bez akuzativu či genitivu | pass_intrans_no
podmínky | diat: pass ¬X2, 4
slovesná forma | se → ∅

1. (25) bojovatimpf ACT1 PATproti+3, za+4

   Potud je jistě správné, když je proti obezitě bojováno.

2. (26) hýbatimpf — hnoutpf1 — hýbnoutpf2 ACT1 PAT7, s+7 DIRtyp BENtyp3

   Jídlo a pití sice zmizely, jinak nebylo s ničím hnuto s výjimkou postele.

Reflexivní slovesa:
U reflexiv tantum nalezené doklady naznačují, že zatímco reflexivum se se při tvoření příznakových konstrukcí daných diatezí odstraňuje, reflexivum si je zachováno:

1. (27) postarat sepf ACT1 PATo+4

   Přestože se děti uprchlíků shodovaly, že je o ně dobře postaráno, část z nich se chce vrátit domů.

2. (28) pohrávat siimpf — pohrát sipf ACT1 PATs+7 MANNtyp

   To jenom když si s jejím srdcem bylo pohráváno jako s nějakou hračkou…

## 1.2 Deagentní diateze

V datové komponentě slovníku je možnost tvořit deagentní konstrukce vyznačena hodnotou atributu diat: deagent; implicitně je touto hodnotou zachycena i možnost vytvářet příznakové struktury dispoziční diateze.

Pro odvození valenčního rámce pro příznakové užití slovesa je nutno na valenční rámec odpovídající nepříznakovému členu diateze zachycený v datové komponentě aplikovat vždy:

- nejprve základní pravidlo deagent_basic (pravidlo G6, odd. 1.2.1), zachycující změny v morfologickém tvaru slovesa a ve shodě a dále nemožnost povrchového vyjádření Konatele ACT;

- a poté (v závislosti na podmínkách kladených na podobu valenčního rámce) právě jedno z doplňkových pravidel uvedených v odd. 1.2.2.

Některá slovesa charakterizuje více možností, jak syntakticky strukturovat příznakové členy deagentní diateze. V takovém případě (nepříznakový) valenční rámec splňuje podmínky pro uplatnění více doplňkových pravidel; pro odvození všech přípustných valenčních rámců pro příznakové užití slovesa se pak aplikují všechny přípustné dvojice základní pravidlo – doplňkové pravidlo.

### 1.2.1 Základní pravidlo

Následující pravidlo zachycuje změny společné všem lexikálním jednotkám sloves, které vytvářejí příznakové konstrukce deagentní diateze:

Deagentní diateze | Pravidlo G6
Základní pravidlo (tvar slovesa, shoda, nemožnost povrchového vyjádření ACT) | deagent_basic
podmínky | diat: deagent ACT1
slovesná forma | se, si → ∅1-10 → 3. osoba aktiva + se
shoda | číslo+rod, X
ACT | ✱ → ∅

Proměnná X, shoda:
Proměnná X označuje – v souladu s výše uvedenou obecnou strukturou pravidel pro diateze, viz úvod kapitoly 1 – to valenční doplnění, které se v příznakovém členu deagentní diateze dostává do subjektové pozice, a se kterým se tak v této konstrukci shoduje slovesný tvar. Základní pravidlo takové doplnění nespecifikuje, uvádějí ho případně až doplňková pravidla pro jednotlivé skupiny sloves (viz dále odd. 1.2.2).
Pokud valenční rámec slovesa doplnění s požadovanými vlastnostmi nemá (jde vždy o doplnění vyjádřené v nepříznakovém členu diateze akuzativem nebo genitivem) nebo pokud je sice takové doplnění ve valenčním rámci identifikováno, v konkrétním užití je však vyjádřeno jinou možnou formou či má charakter (v povrchověsyntaktické struktuře nevyjádřeného) všeobecného aktantu, je shoda realizována neutrální formou, tj. jako neutrum singuláru, viz následující příklady:1-11

1. (29) bránitimpf ACT1 ADDR3 PATv+6, inf, aby MEANStyp7

   X neidentifikovánoBránilo se jim v tom všemi silami.

   (sloveso nemá akuzativní ani genitivní doplnění, slovesný tvar je tedy realizován jako neutrum singuláru)

2. (30) kázatimpf ACT1 ADDRopt3 PAT4, zda, že, cont

   X=PATže Mladším se káže, že starší žijí na úkor mladších.

   (doplnění PAT sice připouští formu akuzativu, je však realizováno jinou možnou formou; slovesný tvar tak má formu neutra singuláru)

3. (31) donášetimpf — donéstpf ACT1 ADDR3 PAT4, zda, že, cont

   X=PAT Za diktatury se běžně donášelo úřadům.

   (akuzativní PAT je na povrchu elidován, slovesný tvar je tedy realizován jako neutrum singuláru)

Vyjádření ACT:
Vedle slovesného tvaru výše uvedené pravidlo určuje, že Konatel (ACT) není v případě příznakových členů deagentní diateze v povrchověsyntaktické struktuře vyjádřen; jde o tzv. všeobecného Konatele.

Reflexivní slovesa:
Ačkoli tvoření deagentní diateze nebylo u reflexivních sloves systematicky anotováno a předpokládáme, že tato slovesa deagentní konstrukce typicky nevytvářejí, teoreticky připouštíme možnost aplikace pravidla G6, deagent_basic, a příslušných doplňkových pravidel též na některá reflexiva tantum a na slovesa s fakultativním reflexivem si. V takovém případě pravidlo G6, deagent_basic, zabrání zdvojení reflexiv odstraněním reflexiva se (32), resp. si (33).

1. (32) modlit seimpf ACT1 ADDRoptk+3 PATopt4 AIMtypza+4, aby

   Tady se modlilo, studovalo, více či méně učeně diskutovalo, téměř nehádalo…

2. (33) poslouchatimpf — poslechnout sipf ACT1 PAT4 EFFjak, že

   Při vizitě se poslechne pacient, jak dýchá, a tím péče končí.

### 1.2.2 Doplňková pravidla

Dále uvádíme doplňková pravidla pro deagentní diatezi, která se uplatňují při derivaci valenčních rámců příznakových konstrukcí pro jednotlivé skupiny sloves v závislosti na podobě jejich nepříznakového valenčního rámce.

V následujících oddílech popisujeme pravidla pro tyto skupiny sloves:

- pravidla pro tranzitivní slovesa, odd. 1.2.2.1, a to:

  - pravidla pro slovesa s akuzativním doplněním, odd. 1.2.2.1a;

  - pravidla pro slovesa s doplněním v genitivu kolísající mezi chováním typickým pro tranzitiva a chováním typickým pro intranzitiva, odd. 1.2.2.1b;

- pravidla pro intranzitivní slovesa, odd. 1.2.2.2, a to:

  - pravidla pro slovesa s doplněním v genitivu, odd. 1.2.2.2a;

  - pravidla pro slovesa bez doplnění v genitivu, odd. 1.2.2.2b.

#### 1.2.2.1 Slovesa tranzitivní (a slovesa s obdobným syntaktickým chováním)

Nejběžnějším typem slovesa, které vstupuje do deagentní diateze, je (stejně jako u pasivní diateze) sloveso tranzitivní, tedy sloveso s akuzativním doplněním, odd. 1.2.2.1a. Některá slovesa s genitivním doplněním ovšem mohou (vzhledem k deagentní diatezi) vykazovat obdobné syntaktické chování, řadíme je proto též do tohoto oddílu, viz 1.2.2.1b.

##### 1.2.2.1a Slovesa s akuzativním doplněním.

Pro lexikální jednotky s akuzativním doplněním se po aplikaci základního pravidla G6, deagent_basic, uplatní následující pravidlo G7, deagent_trans_acc:

Deagentní diateze | Pravidlo G7
Pravidlo pro tranzitivní slovesa (se změnou 4 → 1) | deagent_trans_acc
podmínky | diat: deagent X4
X | 4 → 1
Y | jako+4 → jako+1
| jako+adj-4 → jako+adj-1
| adj-4 → adj-1

Proměnná X, shoda:
Proměnná X zde označuje jakékoli valenční doplnění, jež v nepříznakovém členu diateze může být realizováno akuzativem (nejčastěji PAT, řidčeji EFF nebo ADDR, výjimečně také EXT).1-12 Podle výše uvedeného pravidla G6, deagent_basic, se slovesný tvar shoduje s tímto doplněním v rodě a čísle:

1. (34) krmitimpf ACT1 PAT4 MEANStyp7

   X=PAT4 → 1 Sloni v ZOO se krmí senem.

2. (35) doplňovatimpf — doplnitpf ACT1 PATk+3 EFF4, že, cont

   X=EFF4 → 1 Doplnily se k tomu potřebné údaje.

3. (36) donucovatimpf — donutitpf ACT1 ADDR4 PATdo+2, k+3, inf, aby, ať MEANStyp7

   X=ADDR4 → 1 Vězni se k takovým věcem vždy donucovali.

4. (37) ujítpf ACT1 EXT4

   X=EXT4 → 1 Za den se ušlo dvacet kilometrů.

Proměnná Y:
Také změny u doplnění povrchověsyntakticky realizovaného jako doplněk vyjádřený v nepříznakovém členu diateze jednou z forem jako+4, jako+adj-4 nebo adj-4 jsou shodné jako u pasivní diateze: akuzativ se mění na nominativ tak, že je zachována shoda s doplněním X, ke kterému se doplněk váže:

1. (38) cítitimpf ACT1 PAT4, že EFFjako+4, jako+adj-4

   Y=EFFjako+adj-4 → jako+adj-1 Druhý význam se cítí jako zastaralý.

2. (39) označovatimpf — označitpf ACT1 PAT4 EFFjako+4, za+4, jako+adj-4, za+adj-4 BENtyp3, pro+4

   Y=EFFjako+adj-4 → jako+adj-1 Místo, které zabíral původní soubor, se označí jako volné.

3. (40) udržovatimpf — udržetpf ACT1 PAT4 EFFadj-4, adj-7

   Y=EFFadj-4 → adj-1 Byt se udržuje čistý.

Reflexivní slovesa:
Ačkoli u reflexivních sloves nebylo tvoření deagentní diateze systematicky anotováno, připouštíme aplikaci pravidla G7, deagent_trans_acc, i na ně:

1. (41) modlit seimpf ACT1 ADDRoptk+3 PATopt4 AIMtypza+4, aby

   … a ve tři čtvrtě na dvanáct se v klášteře modlilo před jídlem.

   Při mši o svátku sv. Mikuláše se modlí taky modlitba "abychom jeho zásluhami a přímluvami od pekelných plamenů vysvobozeni byli".

2. (42) osvojovat siimpf — osvojit sipf ACT1 PAT4, zda, že, cont ORIGoptod+2, z+2 MANNtyp

   Špatné stravovací návyky se osvojují velmi brzy.

Slovesa s akuzativním a genitivním doplněním:
A. Pokud se v rámci vyskytují dvě různá doplnění, z nichž jedno má genitivní a druhé akuzativní formu, lze aplikovat pouze pravidlo G7, deagent_trans_acc, které do subjektové pozice přesouvá akuzativní doplnění; genitivní doplnění se subjektem stát nemůže:

1. (43) zbavovatimpf — zbavitpf ACT1 ADDR4 PAT2

   ADDR4 → 1 Práce se zbavila nedostatků.

B. U sloves, u nichž v nepříznakovém členu diateze genitiv alternuje s akuzativem jako morfematická forma téhož valenčního doplnění, uplatníme opět pravidlo G7, deagent_trans_acc. V příznakové konstrukci deagentní diateze se akuzativ dle tohoto pravidla mění na nominativ, zatímco ostatní formy (v tomto případě genitiv) jsou zachovány; u příslušného doplnění tak v příznakovém členu diateze genitiv alternuje s nominativem:

1. (44) docilovatimpf — docílitpf ACT1 PAT2, 4, aby LOCtyp MEANStyp7

   PAT4 → 1 Okrová barva se docilovala vařením vajec s cibulí.

   PAT2 → 2 Dnes se v této disciplíně dociluje neobvyklých úspěchů.

##### 1.2.2.1b Slovesa s doplněním v genitivu kolísající mezi chováním typickým pro tranzitiva a chováním typickým pro intranzitiva.

Další skupinu sloves s genitivním doplněním charakterizuje kolísání mezi chováním typickým pro slovesa s akuzativním doplněním, u nichž v příznakových konstrukcích deagentní diateze dochází ke změně formy genitivního doplnění v nominativní (dané doplnění pak zaplňuje pozici subjektu, pravidlo G8, deagent_trans_gen), a chováním typickým pro slovesa, u nichž k takové změně nedochází (pravidlo G9, deagent_intrans_gen, viz níže odd. 1.2.2.2a).

Deagentní diateze | Pravidlo G8
Doplňkové pravidlo pro rámce s genitivem (se změnou 2 → 1) | deagent_trans_gen
podmínky | diat: deagent X2 & ¬Y4
X | 2 → 1

1. (45) dosahovatimpf — dosáhnoutpf ACT1 PAT2

   pravidlo G8, deagent_trans_gen: X=PAT2 → 1 … inflexní bod je ale před vrcholem, vrchol se dosahuje při tzv. ZEROdp (WWW)

   pravidlo G9, deagent_intrans_gen: X=PAT2 → 2 Pólu se dosahovalo jen s nejvyšším vypětím sil.

Dodejme, že pouze na základě podoby valenčního rámce slovesa a hodnoty atributu diat nelze rozhodnout, zda je možné na dané sloveso aplikovat pouze pravidlo G8, deagent_trans_gen, pouze pravidlo G9, deagent_intrans_gen (viz níže), nebo obě tato pravidla. Jelikož informace o tom, které pravidlo je na dané sloveso třeba aplikovat, není v datové komponentě slovníku VALLEX v současné době uvedena, aplikujeme na všechna slovesa s genitivním doplněním obě pravidla, přestože se tak pro některá slovesa ve výsledném seznamu možných forem příznakového členu diateze mohou objevit i formy, které nejsou korpusovým materiálem doloženy.

#### 1.2.2.2 Slovesa intranzitivní

V tomto oddílu uvádíme pravidla pro odvození rámců pro příznakové konstrukce deagentní diateze u sloves s doplněním v genitivu (odd. 1.2.2.2a) a dále u sloves bez akuzativního a genitivního doplnění (odd. 1.2.2.2b).

##### 1.2.2.2a Intranzitivní slovesa s doplněním v genitivu.

Chování většiny intranzitivních sloves s genitivním doplněním popisuje pravidlo G9, deagent_intrans_gen. Tato slovesa v příznakových konstrukcích deagentní diateze nepřipouštějí transformaci genitivního doplnění v nominativní: formy valenčních doplnění vyjma Konatele jsou tak totožné s formami v nepříznakovém členu diateze.1-13 Na základě pravidla G6, deagent_basic, mají tato slovesa v příznakových konstrukcích deagentní diateze vždy tvar neutra singuláru.

Deagentní diateze | Pravidlo G9
Doplňkové pravidlo pro rámce s genitivem (beze změny formy doplnění) | deagent_intrans_gen
podmínky | diat: deagent Y2 & ¬X4
pouze akce z deagent_basic

1. (46) dbátimpf ACT1 PAT2, na+4

   Y=PAT2 Zákonů se příliš nedbalo.

##### 1.2.2.2b Intranzitivní slovesa bez doplnění v genitivu.

U sloves bez akuzativního a genitivního doplnění jsou změny morfematických forem valenčních doplnění u deagentní diateze popsány pravidlem G10, deagent_intrans_no:

Deagentní diateze | Pravidlo G10
Doplňkové pravidlo pro intranzitivní slovesa | deagent_intrans_no
podmínky | diat: deagent ¬X2, 4
pouze akce z `deagent_basic`

1. (47) hýbatimpf — hnoutpf1 — hýbnoutpf2 ACT1 PAT7, s+7 DIRtyp BENtyp3

   Hýbalo se s nábytkem.

2. (48) pohrávat siimpf — pohrát sipf ACT1 PATs+7 MANNtyp

   si → ∅ …, že víno není žádné pivo, nepije se tudíž v těch barbarských dávkách, ale po kapkách se laská, pohrává se s ním.

## 1.3 Dispoziční diateze

Vzhledem ke shodné morfologické formě slovesa u dispoziční a deagentní diateze předpokládáme, že všechna slovesa, která umožňují tvoření příznakových členů deagentní diateze, tvoří též příznakové členy dispoziční diateze; pro možnost tvořit příznakové členy dispoziční diateze tak není ve slovníku VALLEX zavedena zvláštní hodnota atributu diat.

Příznakový člen dispoziční diateze je u všech sloves tvořen podle téhož pravidla G11, dispositional:

Dispoziční diateze | Pravidlo G11
Pravidlo pro dispoziční diatezi | dispositional
podmínky | diat: deagent ACT1
slovesná forma | se, si → ∅ → 3. osoba aktiva + se
shoda | číslo+rod, X
ACT | ✱ → 3
X | 4 → 1
Y | jako+4 → jako+1
| jako+adj-4 → jako+adj-1
| adj-4 → adj-1
obligatornost | MANN

Slovesná forma:
V příznakovém členu dispoziční diateze je slovesný tvar tvořen tvarem 3. osoby slovesa a reflexivem se.

Reflexivní slovesa:
Pro reflexivní slovesa pravidlo dále specifikuje odstranění původního reflexiva se/si, čímž se zamezuje nepatřičnému zdvojení reflexiva.

1. (49) dívat seimpf ACT1 PATna+4, jak, zda, cont

   … na sparťanské oslavy se mu nedívalo lehce.

2. (50) povídat siimpf ACT1 ADDRs+7 PATopto+6

   Trému jsem neměla a dobře se mi povídalo s moderátorem Honzou Čenským.

Funktor ACT:
Na rozdíl od deagentní diateze může být Konatel (ACT) v příznakovém členu dispoziční diateze vyjádřen, a to dativem. Případy, kdy Konatel není v povrchověsyntaktické struktuře vyjádřen, jsou ovšem častější:

1. (51) spátimpf ACT1 PATopt7 THLtyp MANNtyp

   ACT1 → 3 Špatně se nám spí, ráno se budíme unavení, bez elánu.

   ACT1 → ∅ Všichni se potí, špatně se spí i dýchá…

Proměnná X:
Pokud sloveso ve svém valenčním rámci obsahuje akuzativní doplnění (v pravidle označené proměnnou X; může se jednat o PAT nebo EFF, výjimečně též EXT), akuzativ se u tohoto doplnění mění na nominativ (v příznakové konstrukci tedy zaplňuje povrchověsyntaktickou pozici subjektu) a sloveso se s ním shoduje v čísle a rodě.

1. (52) dávatimpf — dátpf ACT1 ADDRopt3 PAT4

   X=PAT4 → 1 … aby se útočníkům snáze dávaly góly.

2. (53) říkatimpf — říci / říctpf ACT1 ADDRopt3 PATo+6 EFF4, že, cont

   X=EFF4 → 1 Těžko se to o sobě říká, aby to neznělo jako samochvála.

3. (54) ujetpf ACT1 EXT4

   X=EXT4 → 1 Jen na kole je člověk schopen daleko větších zátěží, 50 km se ujede snadno, na rotopedu ujet takovou zátěž je na hlavu.

Proměnná Y:
Pokud valenční rámec vedle akuzativního doplnění obsahuje také doplnění odpovídající povrchověsyntaktickému doplňku realizovanému jednou z morfematických forem jako+4, jako+adj-4 nebo adj-4, dochází ke změně akuzativu v nominativ také u tohoto doplnění:

1. (55) vykládatIIimpf — vyložitIIpf ACT1 PAT4, že, cont EFFjako+4, jako+adj-4 BENtyp3

   Yjako+4 → jako+1 Vyšetřování policie […] se proto snadno vykládá jako pomsta generálům…

Funktor MANN:
Pravidlo pro dispoziční diatezi dále uvádí, že v rámci, který popisuje příznakový člen diateze, se musí vyskytovat obligatorní doplnění způsobu (MANN), a to i tehdy, pokud se toto doplnění ve valenčním rámci odpovídajícím nepříznakovému členu dispoziční diateze nevyskytuje. Toto doplnění je obvykle realizováno hodnoticími adverbii dobře / špatně / snadno / lehce / těžko apod. (viz příklady výše). 1-14

## 1.4 Rezultativní diateze s pomocným slovesem mít (rezultativ posesivní)

Konstrukce s participiem trpným a pomocným slovesem mít vyjadřují tzv. posesivní rezultativ. Jak ukazuje následující příklad, lze je často interpretovat dvěma způsoby:

1. (56) uklízetimpf — ukliditpf ACT1 PAT4
   uvařitpf ACT1 PAT4 ORIGoptz+2 BENtyp3, pro+4
   vyžehlitpf ACT1 PAT4

   poss Nebyla vaše starost, jestli budou mít uklizeno, uvařeno a vyžehleno.

V tomto případě je z hlediska mluvčího irelevantní, zda Konatel (ACT) provádí tyto činnosti sám, nebo zda je pro něj vykonává někdo jiný. Srovnejme tuto větu s následujícími příklady, v nichž lze na základě kontextu rozhodnout, zda subjektu příznakového členu posesivní rezultativní diateze odpovídá Konatel (zde označujeme jako nekonverzní typ), nebo je Konatel z pozice subjektu odsunut (konverzní typ) (k významovým distinkcím u rezultativu viz zejména Panevová et al., 2014 a Giger, 2003):

1. (57)

   possnconv To už bude mít polní kuchyně uvařen vojenský oběd.

   possconv Není to sice úplně ten typ, který musí mít každý den uvařeno, ale rozhodně má rád, když se o něj pečuje.

Ve slovníkové komponentě VALLEXu je možnost vytvářet příznakové konstrukce posesivní rezultativní diateze vyznačena hodnotou poss, jednotlivé příklady jsou podrobněji označeny následujícími hodnotami:1-15

- possnconv: nekonverzní typ, kdy subjektem v příznakové konstrukci zůstává Konatel,

- possconv: konverzní typ, kdy je Konatel v příznakové konstrukci z pozice subjektu odsunut,

- poss: homonymní případy, které lze případně rozlišovat až na základě širšího kontextu.

1. (58) dohrávatimpf — dohrátpf ACT1 ADDRoptproti+3, s+7 PAT4 ACMPtyps+7

   possnconv Také 2. pivní liga má pro letošek dohráno.

   (ve slovníku VALLEX je exemplifikován nekonverzní typ posesivní rezultativní konstrukce, sloveso svým významem umožňuje jen tento typ posesivní rezultativní konstrukce)

2. (59) doporučovatimpf — doporučitpf ACT1 ADDR3 PAT4, inf, aby, ať, zda, že, cont

   possconv My všichni ostatní jsme měli takříkajíc doporučeno nevycházet ven.

   (ve slovníku VALLEX je exemplifikován konverzní typ posesivní rezultativní konstrukce, sloveso umožňuje svým významem pouze tento typ posesivní rezultativní konstrukce)

3. (60) načerpatpf ACT1 PAT4 DIR3typ MEANStyp7

   possnconv Když měl načerpány více než dvě stovky litrů, policejní hlídka ho při krádeži načapala a zatkla.

   (ve slovníku VALLEX je exemplifikována jen nekonverzní konstrukce, ale sloveso umožňuje oba typy konstrukcí)

4. (61) modernizovatbiasp ACT1 PAT4

   possconv Za poloviční částku by senioři měli modernizovány domovy důchodců a penziony.

   (ve slovníku VALLEX je exemplifikována jen konverzní konstrukce, ale sloveso umožňuje oba typy konstrukcí)

### 1.4.1 Posesivní rezultativ nekonverzního typu

Posesivní rezultativní konstrukce nekonverzního typu se tvoří podle následujícího pravidla G12, poss_nconv:

Posesivní rezultativ nekonverzního typu | Pravidlo G12
Subjektem příznakového členu je Konatel | poss_nconv
podmínky | diat: poss ACT1
slovesná forma | → mít + participium trpné, 4. pád1-16 se, si → ∅
shoda | participium trpné: číslo+rod, Y4[PAT|EFF] mít: číslo+rod+osoba, ACT1
ACT | ✱ → 1

U nekonverzního typu posesivní rezultativní diateze nedochází k přeuspořádání valenčních doplnění v povrchověsyntaktické struktuře věty, jako je tomu u ostatních diatezí (Konatel zůstává vyjádřen v prominentní povrchověsyntaktické pozici subjektu). V příznakovém členu se mění pouze morfologický tvar slovesa, který signalizuje výsledkové pojetí děje (Panevová et al., 2014).

Slovesná forma:
Pravidlo G12, poss_nconv, specifikuje, že slovesný tvar je tvořen pomocným slovesem mít a 4. pádem participia trpného.1-17

U posesivního rezultativu se pomocné sloveso mít shoduje v čísle, rodě a osobě s Konatelem, participium trpné se pak shoduje v čísle a rodě s valenčním doplněním vyjádřeným v akuzativu. Pokud sloveso v daném užití akuzativní doplnění nemá nebo toto doplnění není v povrchověsyntaktické struktuře vyjádřeno, má participium trpné formu neutra singuláru.

1. (62) nastupovatimpf — nastoupitpf ACT1 PAT4

   Y= PAT Cestu za návratem do III. třídy mají slušně nastoupenu…

2. (63) nastupovatimpf — nastoupitpf ACT1 PATdo+2, k+3, na+4 COMPLtypjako+1 LOCtyp DIR3typ

   Y neidentifikovánoKorejské automobilky mají na starém kontinentě skutečně nastoupeno k velkému růstu.

Alternativní formy vyjádření Konatele:
Pokud rámec kromě nominativu připouští realizaci Konatele i dalšími formami, jsou tyto formy pravidlem odstraněny:

1. (64) vyžadovat (si)impf — vyžádat (si)pf ACT1, inf PAT2, 4, inf, aby, ať, že ORIGna+6, od+2, po+6

   ACT1,inf → 1 Cizinci mají vyžádáno 202 povolení…

Reflexivní slovesa:
Reflexivum je v příznakové konstrukci posesivního rezultativu nekonverzního typu vypuštěno.

1. (65) domlouvat seimpf — domluvit sepf ACT1 ADDRs+7 PATna+6, o+6, aby, ať, zda, že, cont

   se → ∅ A včera jste si telefonovali a dneska jste se sešli na večeři, jak jste měli domluveno.

2. (66) oblibovat siimpf — oblíbit sipf ACT1 PAT4

   si → ∅ Jiný alkohol konzumují mladí na diskotékách, jiný typ pití mají zase oblíben sportovci.

### 1.4.2 Posesivní rezultativ konverzního typu

Pro odvození valenčního rámce pro příznakovou konstrukci posesivní rezultativní diateze konverzního typu je nutno na valenční rámec zachycený ve slovníkové komponentě (popisující nepříznakový člen diateze) aplikovat vždy:

- právě jedno ze dvou základních pravidel, buďto pravidlo G13, poss_conv_basic1, nebo pravidlo G14, poss_conv_basic2; tato pravidla zachycují změny v morfologickém tvaru slovesa, jeho shodu a dále změny v povrchověsyntaktickém vyjádření dativního doplnění s kognitivní rolí „Recipient“;

- právě jedno z doplňkových pravidel, buďto pravidlo G15, poss_conv_act1, nebo pravidlo G16, poss_conv_act2; tato pravidla zachycují změnu morfematického vyjádření ACT.

#### 1.4.2.1 Základní pravidla určující morfologický tvar slovesa, shodu a vyjádření valenčního doplnění s rolí „Recipient“

Tvoření posesivních rezultativních konstrukcí konverzního typu je popsáno dvěma pravidly, která se odlišují přítomností valenčního doplnění s kognitivní rolí „Recipient“ ve valenčním rámci:

Posesivní rezultativ konverzního typu | Pravidlo G13
Základní pravidlo, v rámci je přítomen „Recipient“ | poss_conv_basic1
podmínky | diat: poss ACT1 & X3[PAT|ADDR|BEN]
slovesná forma | → mít + participium trpné, 4. pád se, si → ∅
shoda | participium trpné: číslo+rod, Y4 mít: číslo+rod+osoba, X
X | ✱ → 1
obligatornost | X

Posesivní rezultativ konverzního typu | Pravidlo G14
Základní pravidlo, v rámci není přítomen „Recipient“ | poss_conv_basic2
podmínky | diat: poss ACT1 & ¬X3[PAT|ADDR|BEN]
slovesná forma | → mít + participium trpné, 4. pád se, si → ∅
shoda | participium trpné, číslo+rod, Y4 mít, číslo+rod+osoba, BEN
obligatornost | BEN1

Slovesná forma:
Charakteristika slovesného tvaru je v obou pravidlech totožná: jedná se o tvar složený z pomocného slovesa mít a participia trpného. Ke shodě slovesných tvarů viz níže poznámky Proměnná X, BEN, shoda a Proměnná Y, shoda. 1-18

Proměnná X, BEN, shoda:
Pro konverzní typ posesivního rezultativu je typická přítomnost situačního participantu s kognitivní rolí „Recipient“, který nekoresponduje s Konatelem; tento participant v pravidle G13, poss_conv_basic1, odpovídá valenčnímu doplnění X a v pravidle G14, poss_conv_basic2, odpovídá (do valenčního rámce doplňovanému) doplnění BEN. V obou případech je „Recipient“ v příznakovém členu diateze realizován nominativem; pomocné sloveso mít se s ním shoduje v čísle, rodu a osobě. 1-19

1. (67) doručovatimpf — doručitpf ACT1 ADDR3 PAT4 DIR3typ

   „Recipient“=ADDR3 → 1 Každý volič by již měl mít doručeny volební lístky.

   (pravidlo G13, poss_conv_basic1: valenční rámec pro nepříznakové užití obsahuje dativní doplnění ADDR s rolí „Recipient“, které se v příznakovém užití přesouvá do subjektové pozice)

2. (68) omlouvatimpf — omluvitpf ACT1 ADDRopt3 PAT4 CAUStyp7, pro+4, za+4, že BENtyp3

   „Recipient“=ADDR3 → 1 Dnes máme celkem omluveno do deseti dětí.

   „Recipient“=BEN3 → 1 Jedna z dívek neměla omluveno 121 a druhá 87 hodin.

   (pravidlo G13, poss_conv_basic1, lze aplikovat dvěma způsoby: za proměnnou X je možné dosadit kterékoli z obou dativních doplnění, nikoli však obě současně)

3. (69) svazovatimpf — svázatpf ACT1 PAT4 EFFoptdo+2, v+4 MEANStyp7

   „Recipient“=BEN → 1 Jeden ji má svázánu v kůži, druhý se spokojil s běžnou verzí, třetímu stačí na výstřižku z novin.

   (pravidlo G14, poss_conv_basic2: valenční rámec pro nepříznakové užití neobsahuje dativní doplnění s kognitivní rolí „Recipienta“, toto doplnění je do rámce odpovídajícího příznakovému členu diateze doplněno jako Benefaktor (BEN) vyjádřený v nominativu)

4. (70) přizpůsobovatimpf — přizpůsobitpf ACT1 PAT4 EFFopt3

   „Recipient“=BEN → 1 Jak dále uvedla, pracovní dobu má každý zaměstnanec přizpůsobenu svému zdravotnímu stavu.

   (pravidlo G14, poss_conv_basic2: valenční rámec slovesa obsahuje dativní EFF (zdravotní stav), které ale nevyjadřuje kognitivní roli „Recipient“; ten je v příznakovém členu diateze realizován jako pravidlem doplněný Benefaktor (BEN) (každý zaměstnanec))

Uveďme též několik příkladů konstrukcí, které sice formálně odpovídají posesivnímu rezultativu, u nichž je však hodnocení valenčního doplnění vyjádřeného v subjektové pozici jako „Recipientu“ sporné.1-20

1. (71) brzditimpf ACT1 PATopt4

   BEN → 1 T11 měla bržděna pouze zadní kola, zatímco T12 měla bržděny obě nápravy.

2. (72) datovatbiasp ACT1 PAT4 MEANStyp7

   BEN → 1 … u selské usedlosti číslo 8, která má štít nad patrovou sýpkou datován 1864 a štít obytné části 1861.

3. (73) deklarovatbiasp ACT1 PAT4 EFFoptjako+4, za+4, jako+adj-4, za+adj-4

   BEN → 1 Kamión měl deklarováno, že převáží kovový šrot.

4. (74) doplňovatimpf — doplnitpf ACT1 PAT4 EFFopt7, o+4

   BEN → 1 Městečka, která jsou navíc na kopci (jako třeba Vrsar nebo Rovinj), mají úzké uličky doplněny o schody.

5. (75) připravovatimpf — připravitpf ACT1 PAT4 EFFoptk+3, na+4 BENtyp3, pro+4

   BEN3, pro+4 → 1 A to i přesto, že nové typy kuchyní mívají už připraveny speciální police na víno.

Proměnná Y, shoda:
Proměnná Y označuje akuzativní valenční doplnění, se kterým se v příznakové konstrukci shoduje participium trpné. Pokud valenční rámec slovesa akuzativní doplnění nemá nebo pokud je takové doplnění ve valenčním rámci sice identifikováno, v konkrétním užití je však vyjádřeno jinou možnou formou, má participium trpné formu neutra singuláru.

1. (76) testovatimpf ACT1 PAT4, zda EFFoptna+4 REGtyp

   Y=PAT4 Mám lyže testovány na jarní sníh, tohle ale byl sníh přemrzlý, s ostrými krystaly, které se zařezávají do skluznic.

   (shoda participia s akuzativním doplněním PAT v čísle a rodě)

2. (77) umožňovatimpf — umožnitpf ACT1 ADDR3 PAT4, inf, aby, že

   Y=PATinf V zařízeních, kde se výuka nepřerušila, měli jednotliví zaměstnanci umožněno se stávky zúčastnit.

   (participium trpné má formu neutra singuláru, jelikož doplnění PAT je realizováno infinitivem)

3. (78) zabraňovatimpf — zabránitpf ACT1 ADDR3 PATv+6, inf, aby

   Y neidentifikovánoPrůměrní uchazeči o studium, zejména bakalářské úrovně, by neměli mít zabráněno v přístupu ke vzdělání jen proto, že nejsou géniové.

   (sloveso nemá akuzativní doplnění, participium tak má formu neutra singuláru)

Specifické chování vykazuje omezená skupina sloves (daných výčtem), u nichž se forma Konatele mění z nominativu na akuzativ; tato změna je ošetřena doplňkovým pravidlem G16, poss_conv_act2, viz níže. U těchto sloves se proměnná Y identifikuje až po aplikaci doplňkového pravidla, příklad (79).

1. (79) zalévat seimpf — zalít sepf ACT1 PATopt7 BENtyp3

   ACT1 → 4 … a oči měl zality slzami.

   (Y je identifikováno jako ACT4 až po aplikaci pravidla G16)

Reflexivní slovesa:
Pravidla G13 a G14 pro tvoření posesivní rezultativní diateze konverzního typu lze aplikovat také na reflexivní slovesa. U sloves s reflexivem se je posesivní rezultativní diateze konverzního typu doložena jen ojediněle (např. sloveso postarat sepf (80)). Omezenou skupinu umožňující vytvářet příznakové konstrukce posesivní rezultativní diateze konverzního typu tvoří slovesa s fakultativním reflexivem si, např. (!missRef!). Reflexiva se/si jsou v obou případech základními pravidly odstraněna.

1. (80) postarat sepf ACT1 PATo+4, aby BENtyp3, pro+4

   Pediatři mají postaráno o práci.

2. (81) říkat (si)impf — říci / říct (si)pf ACT1 ADDRopt3 PAT4, o+4, aby, ať, zda, že

   Měl jsi jasně řečeno, že si máš uklidit pokoj. [příklad vlastní]

#### 1.4.2.2 Doplňková pravidla

Dvě doplňková pravidla zachycují změny morfematické formy Konatele v příznakových konstrukcích posesivního rezultativu konverzního typu. Za základní považujeme změnu popsanou pravidlem G15, poss_conv_act1; okrajově u několika sloves dochází ke změnám popsaným pravidlem G16, poss_conv_act2.

Posesivní rezultativ konverzního typu | Pravidlo G15
Doplňkové pravidlo (centrální typ) | poss_conv_act1
podmínky | diat: poss
ACT | 1 → 7, od+2

1. (82) dávatimpf — dátpf ACT1 ADDR3 PAT4, inf, že, cont EFFoptjako+4, za+4

   ACT1 → 7 Navíc vyšlo najevo, že řidič nemá řidičský průkaz a má soudem dán zákaz řízení.

2. (83) darovatpf ACT1 ADDR3 PAT4 CAUStypk+3 AIMtypna+4 RCMPtypza+4

   ACT1 → od+2 Musí mít nemálo darováno od Pánaboha, který dává nejen talent, ale také lásku k této jedné z nejkrásnějších múz.

Jak je pro tuto diatezi typické, zůstává Konatel (ACT) v konkrétních užitích často nevyjádřený (viz příklady (67)–(!missRef!) výše).

Slovníková komponenta VALLEXu zachycuje pouze dvě lexikální jednotky reflexivních sloves, které umožňují tvořit posesivní rezultativ konverzního typu podle tohoto pravidla:1-21

1. (84) postarat sepf ACT1 PATo+4, aby BENtyp3, pro+4

   ACT1 → od+2 Takže o tlak na sportovní výsledky mám postaráno od ní.

2. (85) spojovat siimpf — spojit sipf ACT1 PAT4 EFFs+7

   … vyzývá sponzory, aby zvážili, zda chtějí mít své jméno spojováno s krvavou olympiádou.

   (ACT nevyjádřen)

U několika sloves daných výčtem (typicky odvozených reflexivních sloves) dochází ke změně formy Konatele z nominativu na akuzativ:1-22

Posesivní rezultativ konverzního typu | Pravidlo G16
Doplňkové pravidlo (okrajový typ) | poss_conv_act2
podmínky | diat: poss
Y[ACT] | 1 → 4

1. (86) svírat seimpf — sevřít sepf ACT1 PAToptdo+2, v+4 MANNtyp CAUStyp7 BENtyp3

   ACT1 → 4 Chtěla vykřiknout, ale nemohla, hrdlo měla sevřeno.

2. (87) vyvíjet seimpf — vyvinout sepf ACT1 PAToptz+2 BENtyp3

   ACT1 → 4 Jsou však i tací motýli, kterým tyto potravní požitky v jejich krátkém životě nic neříkají, protože nemají vyvinuty zažívací orgány.

3. (88) usazovat seimpf — usadit sepf ACT1 LOC

   ACT1 → 4 Pouze s výjimkou těch nejstarších kusů, které ve svém těle mají nadále usazeny škodlivé látky z té doby.

## 1.5 Recipientní pasivní diateze

V datové komponentě slovníku je možnost tvořit recipientní pasivní konstrukce vyznačena hodnotou atributu diat: recipient. Příznakové konstrukce této diateze se tvoří u všech sloves, která ji umožňují, na základě jediného pravidla G17, recipient:

Recipientní diateze | Pravidlo G17
Společné pravidlo | recipient
podmínky | diat: recipient ACT1 & X3[PAT|ADDR|BEN]
slovesná forma | → dostat|dostávat + participium trpné, 4. pád1-23
shoda | participium trpné: číslo+rod, Y4[PAT|EFF] dostat|dostávat: číslo+rod+osoba, X
ACT | ✱ → od+2, (7)
X | ✱ → 1
obligatornost | X

Podmínka na tvar valenčního rámce:
Recipientní pasivní diateze je ve slovníkové komponentě VALLEXu vyznačena jen u těch sloves, která mají ve svém valenčním rámci PAT, ADDR nebo BEN v dativu.1-24

Proměnné X, Y, shoda:
Recipientní pasivní diateze se vyznačuje shodou participia trpného s akuzativním doplněním (v pravidle G17, recipient, je toto doplnění označeno proměnnou Y); pokud se ve valenčním rámci akuzativní doplnění nevyskytuje či v daném užití není povrchověsyntakticky vyjádřeno, je participium trpné ve tvaru neutra singuláru.
Pomocné sloveso dostat/dostávat se v rodě, čísle a osobě shoduje s valenčním doplněním (v pravidle G17, recipient, označeným proměnnou X), které odpovídá PAT, ADDR nebo BEN.

Vyjádření proměnné X:
Doplnění X mění v příznakové konstrukci recipientní pasivní diateze své morfematické vyjádření z dativu či libovolné další formy přípustné v aktivní konstrukci na nominativ.

1. (89) vyčinitIpf ACT1 PAT3 CAUStypza+4

   X=PAT3 → 1, Y neidentifikovánoODS dostala vyčiněno za nerespektování vůle voličů.

2. (90) rozdělovatimpf1 — rozdíletimpf2 — rozdělitpf ACT1 ADDR3, mezi+4 PAT4 MEANStyp7 LOCtyp BENtyp3, pro+4

   X=ADDR3, mezi+4 → 1, Y=PAT Vaši rádcové už dostali rozděleny úkoly, co je potřeba zařídit, takže vás brzy pořádně zaměstnají.

3. (91) vyhrazovatIimpf — vyhraditIpf ACT1 PAT4 BENtyp3, pro+4 AIMtypk+3, na+4, pro+4

   X=BEN3, pro+4 → 1, Y=PAT Jeho vláda prosadila, aby ženy v parlamentu dostaly vyhrazenu nejméně třetinu křesel.

Vyjádření ACT:
Konatel může být v příznakové konstrukci recipientní pasivní diateze vyjádřen předložkovou skupinou od+2 (výjimečně též instrumentálem), nebo zůstává povrchověsyntakticky nevyjádřený:

1. (92) doplácetimpf — doplatitpf ACT1 ADDRopt3 PAT4 EFFoptk+3 RCMPtypza+4 AIMtypna+4

   ACT1 → od+2 Lidé s nízkými příjmy by tak podobně jako u daňového bonusu dostali od státu doplaceno.

2. (93) nařizovatIIimpf — naříditIIpf ACT1 ADDR3 PAT4, inf, aby, ať, že

   ACT1 → 7 Co by mělo zůstat v pravomoci nemocnic a co by dostaly nařízeno vedením, není zatím určeno.

3. (94) předepisovat / předpisovatimpf — předepsatpf ACT1 ADDR3 PAT4, inf, aby, ať, zda, že, cont

   ACT1 → 7 Nova […] nedostala předepsáno zákonem, jak má vypadat zpravodajství a jaké publicistické pořady má vysílat…

Reflexivní slovesa:
Možnost reflexivních sloves vstupovat do recipientní pasivní diateze dosavadní zpracování sloves ve VALLEXu nepotvrdilo, pravidlo proto takovou možnost neošetřuje.

# 2 Syntaktická reflexivita

V konstrukcích, které zde označujeme jako syntaktickou reflexivitu, vyjadřuje reflexivní osobní zájmeno referenční totožnost aktantu jím vyjádřeného a aktantu v subjektové pozici, typicky Konatele (ACT), např. Petr se viděl v zrcadle. ≈ Petr viděl sám sebe (= Petra) (viz Karlík et al., 2002, s. 414, zde odd. THEORY > 2). Ve VALLEXu je možnost reflexivního užití zachycena v atributu refl,2-25 který může nabývat hodnoty coref3 (týká-li se reflexivita doplnění s dativní formou), či coref4 (pro doplnění s akuzativní formou).

Případy syntaktické reflexivity popisuje jedno základní pravidlo pro reflexivní konstrukce s reflexivním osobním zájmenem v dativu, pravidlo G18, reflex_basic_3, odd. 2.1, a jedno základní pravidlo pro reflexivní konstrukce s reflexivním zájmenem v akuzativu, pravidlo G19, reflex_basic_4, odd. 2.2.1. Základní pravidlo pro konstrukce s akuzativním reflexivním zájmenem doplňují dvě pravidla ošetřující tvar doplňku, pravidlo G20, reflex_compl_se, a pravidlo G21, reflex_compl_sebe, odd. 2.2.2. Tato pravidla se aplikují vždy na valenční rámec zachycený v datové komponentě slovníku, který odpovídá nereflexivnímu užití slovesa.2-26

Zde uváděná pravidla pro odvození valenčních rámců pro reflexivní konstrukce mají následující strukturu:

Typ reflexivity | Pravidlo
Podtyp reflexivity | Název pravidla
podmínka | reflex: typ reflexivity (tedy coref3 nebo coref4) Podmínky na valenční rámec
FUNKTOR | Seznam změn v morfologické realizaci daného doplnění
obligatornost | Valenční doplnění vyjádřené reflexivním osobním zájmenem, které je v příznakovém členu reflexivní alternace obligatorně povrchově vyjádřeno

Při formulaci jednotlivých pravidel používáme následující značení:

Podmínky na uplatnění pravidla
Příslušné pravidlo pro odvození valenčních rámců pro reflexivní konstrukce se může uplatnit jen na valenční rámce lexikálních jednotek s atributem refl nesoucím příslušnou hodnotu (tedy coref3 nebo coref4), a to pokud splňují v pravidle specifikované podmínky na valenční rámec.

X, Y a Z: Proměnné pro funktory
Symboly X, Y a Z užívané v pravidlech představují proměnné, které zastupují valenční doplnění s různými funktory. Pokud chceme omezit množinu funktorů, které mohou být hodnotou dané proměnné, píšeme např. Y[PAT|ADDR] (Y je buď Patiens, nebo Adresát).
Proměnná X má výsadní postavení, používáme ji pro to valenční doplnění, které je v subjektové pozici.

Xi: Podmínky na valenční doplnění
Zápis Yi určuje valenční doplnění (dané proměnnou Y) spolu s jeho požadovanou morfematickou formou (či posloupností morfematických forem), jehož přítomnost je pro uplatnění daného pravidla požadována, např. podmínka "Y2, 4" požaduje přítomnost libovolného doplnění, které (vedle případných dalších forem) umožňuje realizaci genitivem či akuzativem.

i → j, ∅: Změny morfematických forem
Uvedené symboly užíváme při popisu změn morfematických forem valenčních doplnění. Tyto změny jsou zapsány ve formátu "seznam forem doplnění v nepříznakové konstrukci → seznam forem doplnění v příznakové konstrukci", např. "4 → 1" označuje, že doplnění uvedené ve valenčním rámci jako akuzativní se v příznakové konstrukci mění na nominativní.
Symbol ∅ vyskytující se na pravé straně pravidel označuje, že příslušné valenční doplnění nemůže být v příznakové konstrukci v povrchověsyntaktické struktuře vyjádřeno.

## 2.1 Syntaktická reflexivita dativního doplnění

Syntaktická reflexivita dativního doplnění | Pravidlo G18
Reflexivita zasahuje doplnění s možnou dativní formou | reflex_basic_3
podmínka | reflex: coref3 X1[ACT|PAT] & Y3[PAT|ADDR|BEN|ACT]
Y | 3 → si, sobě
| předložka+pád → předložka+reflexivní zájmeno v příslušném dlouhém tvaru2-27, 2-28
| ostatní formy → ∅
obligatornost | Y

Podmínky na přítomná valenční doplnění:
V reflexivních konstrukcích s dativním doplněním (refl s hodnotou coref3) proměnná X typicky označuje nominativního Konatele (ACT) a proměnná Y dativní doplnění s funktorem ADDR nebo BEN, případně (v důsledku posouvání aktantů) též s funktorem PAT:

1. (95) bránitimpf ACT1 ADDR3 PATv+6, inf, aby MEANStyp7

   X=ACT, Y=ADDR3 → si, sobě Svým nevhodným chováním si brání v kariérním postupu.

2. (96) udržovatimpf — udržetpf ACT1 PAT4 BENtyp3, pro+4

   X=ACT, Y=BEN3 → si, sobě Udržoval si stále první místo.

3. (97) pouštětimpf — pustitpf ACT1 PAT3 DPHRžilou

   X=ACT, Y=PAT3 → si, sobě Sám si často pouštěl žilou.

4. (98) vyčítatimpf — vyčístpf ACT1 ADDR3 PAT4, že, cont

   X=ACT, Y=ADDR3 → si, sobě Pokud o léčbu nepožádáme, můžeme následky vyčítat pouze sami sobě.

Okrajově u sloves s dativním proživatelem proměnná X odpovídá PAT vyjádřenému v nominativu a Y odpovídá dativnímu ACT:

1. (99) přijítpf ACT3 PAT1, že EFFjako+1, adj-1, adj-7, jako+adj-1, být+adj-1, být+adj-7

   X=PAT, Y=ACT3 → si, sobě Přijde si příliš tlustá.

2. (100) připadatIimpf — připadnoutIpf ACT3 PAT1, že EFFadj-1, adj-7, jako+adj-1, být+adj-1, být+adj-7

   X=PAT, Y=ACT3 → si, sobě Připadal si neohrabaný.

Výjimečně se ve valenčním rámci mohou vyskytnout dativní doplnění dvě; v takovém případě může být pravidlo G18, reflex_basic_3, uplatněno dvěma způsoby, za Y lze dosadit kterékoli z těchto doplnění (nikoli však obě současně):

1. (101) platitimpf ACT1 ADDRopt3 PAT4 RCMPtypod+2, za+4 AIMtypna+4 SUBStypza+4 LOCtyp BENtyp3, pro+4

   X=ACT, Y=BEN3 → si, sobě Soukromníci si hubení hlodavců platí sami.

   X=ACT, Y=ADDR3 → si, sobě Částečně ve svém úřaduje třeba i zlínský poslanec ODS Pavel Svoboda. Zřídil si kancelář v domě s více majiteli – dva z nich jsou ale on sám a jeho asistent. Platí si 21 200 korun, nejvíc co jde.

Obligatornost:
Jak ukazují příklady (96) a (101), doplnění Y může být ve valenčním rámci některých sloves fakultativní; v reflexivních konstrukcích je však toto doplnění nutně přítomno (jinak by reflexivita nebyla vyjádřena), viz pravidlo G18, reflex_basic_3. Toto doplnění může být v reflexivní konstrukci realizováno pouze reflexivním zájmenem v příslušném tvaru.

Klitická vs. dlouhá forma reflexivního zájmena:
Volba krátké (klitické) či dlouhé formy reflexivního zájmena je dána zejména faktory souvisejícími s aktuálním členěním (vyjádřeným především slovosledem a prozódií, Daneš et al., 1987; Hajičová, 2007):

1. (102) odporovatimpf ACT1 PAT3 REGtypv+6

   Y=PAT3 → si, sobě Každou větou odporují sami sobě.

   (reflexivní pojetí děje je dále zdůrazněno užitím zájmena sám)

2. (103) vládnoutimpf ACT1 PATopt3, nad+7 MANNtyp MEANStyp7 LOCtyp

   Y=PAT3 → si, sobě Nemusí o sobě rozhodovat a sobě vládnout.

   (z důvodů aktuálního členění (přesun slovesa do nejdynamičtější pozice) je užita dlouhá forma reflexivního zájmena)

3. (104) důvěřovatimpf ACT1 PAT3 EFFoptže REGtypv+6

   Y=PAT3 → si, sobě Nezbývá nám tak nic jiného než důvěřovat sobě a svému rozumu.

   (v koordinaci nelze užít krátkou formu reflexivního zájmena)

Reflexivní význam dané konstrukce může být zdůrazněn užitím zájmena sám, příklady (97) a (102).

Předložkové pády jako alternativní forma k dativu:
Typickým předložkovým pádem, který se v rámcích vyskytuje jako alternativa k dativu, je forma pro+4 u Benefaktoru (BEN); dále se u jedné lexikální jednotky objevuje forma nad+7, u jedné forma před+7:

1. (105) chystatimpf ACT1 PAT4 ORIGoptz+2 BENtyp3, pro+4

   Y=BENpro+4 → pro sebe Teď chystají samy pro sebe adventní kalendáře.

2. (106) vládnoutimpf ACT1 PATopt3, nad+7 MANNtyp MEANStyp7 LOCtyp

   Y=PATnad+7 → nad sebou Jen kdo nad sebou vládne, jest opravdu svoboden.

3. (107) uzavíratimpf — uzavřítpf ACT1 PAT4 BENtyp3, pro+4, před+7

   Y=BENpřed+7 → před sebou … jako by před sebou uzavírala brány života.

Všechny povrchové formy doplnění Y vyjma dativu a předložkových pádů jsou pravidlem odstraněny (neboť se nemohou uplatnit v reflexivních konstrukcích):

1. (108) naslouchatimpf ACT1 PAT3, jak, zda, cont

   Y=PAT3, jak, zda, cont → si, sobě Naslouchej si trochu!

## 2.2 Syntaktická reflexivita akuzativního doplnění

Valenční rámec odpovídající reflexivní konstrukci s akuzativním doplněním je tvořen z nepříznakového valenčního rámce na základě následujícího základního pravidla G19, reflex_basic_4. Na rámce, které obsahují doplnění vyjádřitelné jednou z forem jako+4 či jako+adj-4, je navíc nutné aplikovat jedno z doplňkových pravidel ošetřujících shodu doplňku, buď pravidlo G20, reflex_compl_se, nebo G21, reflex_compl_sebe.

### 2.2.1 Základní pravidlo pro akuzativní reflexivní konstrukce

Syntaktická reflexivita akuzativního doplnění | Pravidlo G19
Reflexivita zasahuje doplnění s možnou akuzativní formou | reflex_basic_4
podmínka | reflex: coref4 ACT1 & Y4[PAT|ADDR]
Y | 4 → se, sebe
| předložka+pád → předložka+reflexivní zájmeno v příslušném tvaru2-29, 2-30
| ostatní formy → ∅
obligatornost | Y

Podmínky na přítomná valenční doplnění:
Pro reflexivní konstrukci s akuzativním doplněním (refl s hodnotou coref4) rámec obsahuje nominativního Konatele (ACT), proměnná Y pak označuje akuzativní doplnění s funktorem PAT nebo ADDR.

Vyjádření valenčního doplnění zasaženého reflexivitou:
Doplnění Y může být v reflexivní konstrukci vyjádřeno pouze reflexivním osobním zájmenem v příslušném tvaru. Volba krátké (klitické) či dlouhé formy reflexivního zájmena je dána zejména faktory souvisejícími s aktuálním členěním (vyjádřeným především slovosledem a prozódií, Daneš et al., 1987; Hajičová, 2007):

Reflexivní význam dané konstrukce může být zdůrazněn užitím zájmena sám.

1. (109) bránitimpf ACT1 PAT4 EFFoptproti+3, před+7

   Y=PAT4 → se, sebe Mladík se bránil rukama. Brání sám sebe, ne mě.

2. (110) obviňovatimpf — obvinitpf ACT1 ADDR4 PATz+2, že

   Y=ADDR4 → se, sebe … a nyní se obviňuje z jakéhosi ohavného nevysvětlitelného zločinu. Simba přece nebyl blázen a nechtěl sám sebe obvinit.

Pravidlo počítá i s možností alternativního vyjádření předložkovým pádem, viz příklad (111). Dále některé lexikální jednotky připouštějí jako alternativu k akuzativu obsahovou závislou klauzi; ta však neumožňuje reflexivizaci, a je tedy pravidlem bez náhrady odstraněna, viz příklad (112):

1. (111) nahlížetimpf — nahlédnoutpf ACT1 PAT4, na+4 EFFjako+4, jako na+4, jako+adj-4

   Y=PATna+4 → na sebe Řada klientů na sebe nahlíží jako na líné, neschopné a k lékaři přichází často po několika letech, kdy má obtíže.

2. (112) nenávidětimpf ACT1 PAT4, inf, že, cont CAUStypkvůli+3, pro+4, za+4

   Y=PAT4, inf, že, cont → se, sebe Nenáviděla se za to, ale nebyla toho schopna! Teď vážně nenávidím sám sebe.

Obligatornost:
Doplnění Y může být ve valenčním rámci některých sloves fakultativní, např. (113); v reflexivních konstrukcích je však toto doplnění nutně přítomno (jinak by reflexivita nemohla být vyjádřena), viz pravidlo G19, reflex_basic_4. Toto doplnění může být v reflexivní konstrukci realizováno pouze reflexivním zájmenem v příslušném tvaru.

1. (113) zatahovatimpf — zatáhnoutpf1 — zatahatpf2 ACT1 PATopt4 MEANStyp7, za+4

   Y=PAT4 → se, sebe Zatahal se za vousy.

### 2.2.2 Doplňková pravidla pro rámce s jako+4 a jako+adj-4

Syntaktická reflexivita v jistých případech ovlivňuje i shodu doplňku; tyto případy jsou ošetřeny doplňkovými pravidly.

Pokud je v reflexivní konstrukci s akuzativem přítomen doplněk s formou jako+4 či jako+adj-4, může (oproti nereflexivní konstrukci) docházet ke změně jeho morfematického vyjádření, a to v závislosti na formě reflexiva. V užitích s dlouhou formou reflexiva sebe se doplněk (stejně jako v případě, že je daná valenční pozice vyjádřena substantivem či osobním nereflexivním zájmenem) shoduje s daným reflexivem, srov. Ivo Krajíček.ACT(1) sám sebe.PAT(4) charakterizuje jako šílence.COMPL(jako+4), který si dělá, co sám chce., ovšem v užitích s klitickým reflexivem se doplněk typicky shoduje se subjektem, srov. (on).ACT(1) Nechal se.PAT(4) zaměstnat jako nosič.COMPL(1) kufrů… Korpusová data přesto dokládají řídké příklady shody s akuzativním klitickým reflexivem, srov. (vy).ACT(1) Vnímáte se.PAT(4) jako vlnu.EFF(jako+4), cítíte mezi sebou sounáležitost?. Syntaktické a sémantické faktory ovlivňující shodu popisují Kettnerová et al. (2015); k motivaci viz i Wagner (2014).

Změny ve valenčním rámci slovesa typické pro reflexivní konstrukce s klitickou formou reflexivního zájmena jsou ošetřeny pravidlem G20, reflex_compl_se. Pravidlo G21, reflex_compl_sebe, pak zachycuje dané změny v reflexivních konstrukcích s dlouhou formu reflexiva.

Syntaktická reflexivita akuzativního doplnění | Pravidlo G20
Doplňkové pravidlo pro doplněk s jako, reflexivum se | reflex_compl_se
podmínka | reflex: coref4 Zjako+4, jako+adj-4[EFF|COMPL]
Y | se, sebe → se
| předložka+pád → ∅2-31
Z | jako+4 → jako+1, jako+4
| jako+adj-4 → jako+adj-1, jako+adj-4 2-32

Syntaktická reflexivita akuzativního doplnění | Pravidlo G21
Doplňkové pravidlo pro doplněk s jako, reflexivum sebe | reflex_compl_sebe
podmínka | reflex: coref4 Zjako+4, jako+adj-4[EFF|COMPL]
Y | se, sebe → sebe
| ostatní formy zůstávají beze změn
Z | formy zůstávají beze změn

1. (114) zapisovatimpf — zapsatpf ACT1 PAT4 DIR3 COMPLtypjako+4, jako+adj-4

   pravidlo G20: Y=PAT4 → se, Z=COMPLjako+4 → jako+1 Po vypuknutí první světové války se zapsal jako dobrovolník České družiny, která se stala základem budování československých legií v Rusku.

   pravidlo G21: Y=PAT4 → sebe, Z=COMPLjako+4 Roman byl z jednatelství vymazán a na jeho místo zapsala Kateřina [jako potencionální dědičku] sebe.

2. (115) vnímatimpf ACT1 PAT4, že EFFjako+4, jako+adj-4

   pravidlo G20: Y=PAT4 → se, Z=EFFjako+4 → jako+1 Vnímal se jako oběť.

   pravidlo G20: Y=PAT4 → se, Z=EFFjako+4 → jako+4 Vnímáte se jako vlnu, cítíte mezi sebou sounáležitost?

   pravidlo G21: Y=PAT4 → sebe, Z=EFFjako+4 Sebe vnímal jako oběť, nikoli jako viníka.

3. (116) nahlížetimpf — nahlédnoutpf ACT1 PAT4, na+4 EFFjako+4, jako na+4, jako+adj-4

   pravidlo G20: Y=PAT4 → se, Z=EFFjako+4 → jako+1 Sám se totiž vždy nahlížel jako kulturní člověk.

   pravidlo G21: Y=PAT4 → sebe, Z=EFFjako+4 Sama sebe nahlíží jako titána současné české žurnalistiky.

   pravidlo G21: Y=PATna+4 → na sebe, Z=EFFjako na+4 Nahlížejte na sebe jako na člověka majícího v daný okamžik celý svět u nohou.

Obě pravidla ponechávají ostatní formy doplnění Z beze změny:

1. (117) vidětimpf ACT1 PAT4 EFF7, jako+4, adj-4, jako+adj-4

   PAT4 → se, sebe, Z=EFF7 Izraelci se vidí pětinásobnými vítězi nad Araby.

2. (118) uznávatimpf — uznatpf ACT1 PAT4, že, cont EFFjako+4, za+4, adj-7, jako+adj-4

   PAT4 → se, sebe, Z=EFFza+4 Zároveň nabídl Tchaj-wanu dialog pod podmínkou, že sám sebe uzná za součást Číny.

# 3 Reciprocita

V recipročních konstrukcích vstupují dva situační participanty (případně více participantů) do vztahu symetrie; v důsledku toho každý ze zasažených situačních participantů koresponduje se dvěma (či více) valenčními doplněními. Valenční doplnění obsazující výše postavenou pozici je pak vyjádřeno plurálem, koordinační skupinou, příp. kolektivem, syntaktická pozice níže postaveného valenčního doplnění je typicky vyjádřena reflexivním osobním zájmenem, a to obligatorně (je-li reciprocitou zasažen subjekt), nebo fakultativně (není-li subjekt zasažen) 3-33 (viz Panevová, 1999; Panevová, 2007; Panevová – Mikulová, 2007, zde kapitola THEORY, odd. THEORY > 2).

Vzhledem k tomu, že reciprocita v češtině představuje značně rozsáhlý jazykový jev, který dosud nebyl dostatečně prozkoumán, uvádíme možný pravidlový popis pouze pro dva typy reciprocity: pro reciprocitu ACT a ADDR, zasahující pozici subjektu, odd. 3.1, a pro reciprocitu PAT a EFF, zasahující pozici přímého objektu, odd. 3.2. Předpokládáme, že další typy reciprocity lze popsat obdobným způsobem.

Ve VALLEXu je možnost lexikálních jednotek tvořit reciproční konstrukce zachycena v datové komponentě v atributu recipr. Reciprocita je vyznačena u lexikálních jednotek sloves, u nichž vstupují do vztahu symetrie aktanty, kvazivalenční doplnění a obligatorní volná doplnění (reciprocita těchto doplnění a doplnění typických ani reciprocita typických doplnění vyznačena není).

Zde uváděná pravidla pro odvození valenčních rámců pro reciproční konstrukce mají následující strukturu:

Typ reciprocity | Pravidlo
Charakteristika pravidla | Název pravidla
podmínky | recipr: Hodnota atributu recipr Podmínky na valenční rámec a reflexivitu
shoda | Specifikace tvaru slovesa na základě shody
FUNKTOR | Změny morfematických forem u valenčního doplnění s daným funktorem
obligatornost | Valenční doplnění, které je v reciproční konstrukci obligatorně povrchově vyjádřeno, příp. adverbia obligatorně přítomná v reciproční konstrukci
zdůraznění | Výrazy, které lze použít ke zdůraznění recipročního významu

Podmínky na uplatnění pravidla
Příslušné pravidlo pro odvození valenčních rámců pro reciproční konstrukce se může uplatnit jen na valenční rámce lexikálních jednotek s atributem recipr nesoucím příslušnou hodnotu (tedy ACT-ADDR nebo PAT-EFF), a to pokud splňují další podmínky specifikované v pravidle (týkající se podoby valenčního rámce a reflexivity slovesa, viz dále).

Xi: Podmínky na valenční doplnění
K reciprocitě se vztahují podmínky specifikující valenční doplnění, jehož přítomnost v rámci je pro uplatnění daného pravidla požadována. Podmínky označují požadovanou morfematickou formu či posloupnost morfematických forem, např. podmínka "ACT1" požaduje přítomnost Konatele, který (vedle případných jiných forem) umožňuje realizaci nominativem, "ADDRk+3, na+4" požaduje přítomnost Adresátu, který (vedle případných dalších forem) umožňuje realizaci alespoň jednou z uvedených forem.

SE|SI, ¬SE|SI: Podmínky na reflexivitu slovesa
Tento typ podmínky specifikuje (pokud je to relevantní), zda lze pravidlo uplatnit pouze na slovesa s reflexivním lemmatem (SE|SI), nebo pouze na slovesa nereflexivní (¬SE|SI).

i → j, ✱, ∅: Změny morfematických forem
Uvedené symboly užíváme při popisu změn morfematických forem valenčních doplnění. Tyto změny jsou zapsány ve formátu "seznam forem doplnění v nereciproční konstrukci → seznam forem doplnění v příznakové konstrukci", např. "4 → 1" označuje, že doplnění uvedené v rámci jako akuzativní doplnění se v reciproční konstrukci mění na nominativní.
Pokud se mají nahradit všechny formy, kterými může být v nereciproční konstrukci dané doplnění realizováno, používáme na levé straně pravidla symbol ✱.
Symbol ∅ vyskytující se na pravé straně pravidel označuje, že příslušné valenční doplnění není v příznakové konstrukci v povrchověsyntaktické struktuře vyjádřeno.

## 3.1 Reciprocita Konatele a Adresátu

Reciprocita Konatele (ACT) a Adresátu (ADDR) je v datové komponentě slovníku vyznačena hodnotou atributu recipr: ACT-ADDR. Pro odvození reciproční konstrukce je třeba na valenční rámec zachycený v datové komponentě slovníku, který odpovídá nerecipročnímu užití,3-34 aplikovat:

- nejprve základní pravidlo G22, viz odd. 3.1.1, které popisuje změny ve shodě a v morfematické realizaci subjektu;

- a poté (v závislosti na podmínkách kladených na podobu valenčního rámce a na tom, zda má sloveso reflexivní podobu či ne) právě jedno z doplňkových pravidel uvedených v odd. 3.1.2; tato pravidla popisují změny v morfematickém vyjádření Adresátu (ADDR) a zachycují, jakými výrazy je možné reciproční pojetí děje zdůraznit.

Řadu sloves charakterizuje více možností, jak v recipročních konstrukcích vyjádřit ADDR; v takových případech se aplikují všechny přípustné dvojice základní pravidlo – doplňkové pravidlo.

### 3.1.1 Základní pravidlo

Následující pravidlo popisuje změny v recipročních konstrukcích společné pro všechny lexikální jednotky sloves s reciprocitou nominativního Konatele (ACT) a Adresátu (ADDR) vyjádřeného různými morfematickými formami.3-35

Reciprocita ACT-ADDR | Pravidlo G22
Pravidlo (forma slovesa, shoda, změna formy doplnění) | recipr_subj_basic
podmínky | recipr: ACT-ADDR ACT1 & ADDR
shoda | číslo+rod+osoba, ACT
ACT | ✱ → 1: plurál

Vyjádření ACT:
Předpokládáme, že při reciprocitě Konatele (ACT) a Adresátu (ADDR) odpovídá ACT (stejně jako ADDR) dvěma situačním participantům, kteří jsou ve vztahu symetrie. Subjektová pozice, v níž je ACT vyjádřen, tak odpovídá oběma zasaženým situačním participantům; důsledkem této korespondence je, že subjekt je typicky obsazen substantivy vyjádřenými v plurálu, substantivy koordinovanými paratakticky nebo hypotakticky, příp. jde o jména formálně vyjádřená singulárem, ale s významem plurálovým, o tzv. kolektiva, viz Mluvnici češtiny 2 (Komárek et al., 1986).

1. (119) obviňovatimpf — obvinitpf ACT1 ADDR4 PATz+2, že

   ACT1: plurál Obě strany se poté navzájem obvinily z tvrdohlavosti.

   ACT1: parataktická koordinace Teplický soud a ministerstvo se navzájem obviňují z toho, že jména na internetu zpřístupnily.

   ACT1: hypotaktická koordinace … kde se Dvořák se Svobodou vzájemně a veřejně obvinili ze všech možných hříchů.

2. (120) předávatimpf — předatpf ACT1 ADDR3 PAT4

   ACT1: kolektivum Celá třída už si vzájemně předala informace tichou poštou.

Pokud rámec slovesa umožňujícího reciprocitu ACT a ADDR připouští kromě nominativu realizaci Konatele i dalšími formami, jsou tyto formy pravidlem odstraněny:

1. (121) působitimpf ACT1, že, cont ADDRoptna+4, proti+3 PATopt7 AIMtypaby MANNtyp

   ACT1, že, cont → 1 Hrají tam roli další faktory a působí na sebe navzájem?

### 3.1.2 Doplňková pravidla

Syntaktická pozice vyjadřující ADDR je typicky obsazena reflexivním osobním zájmenem vyjádřeným v morfematickém tvaru, kterým je dané doplnění charakterizováno ve valenčním rámci popisujícím nereciproční strukturu.

Doplňková pravidla popisují změny ve vyjádření ADDR a dále zachycují, jakými výrazy je možné zdůraznit reciproční pojetí děje.

Tabulka na protější straně podává základní přehled forem reflexivního osobního zájmena v recipročních konstrukcích s reciprocitou ACT-ADDR, podrobnou analýzu zachycují až jednotlivá pravidla.

#### 3.1.2.1 Reciprocita nominativního Konatele a dativního Adresátu

Reciprocitu nominativního Konatele (ACT) a dativního Adresátu (ADDR) popisují dvě doplňková pravidla, pravidlo G23, ACT(1)-ADDR(3)_nerefl, pro slovesa nereflexivní, odd. 3.1.2.1a, a pravidlo G24, ACT(1)-ADDR(3)_refl, pro slovesa reflexivní, odd. 3.1.2.1b. Slovesa s fakultativním reflexivem se/si se zpracovávají v závislosti na přítomnosti tohoto reflexiva v daném užití slovesa podle příslušného pravidla.

TABLE!

##### 3.1.2.1a Reciprocita nereflexivních sloves s dativním Adresátem.

Změny ve valenčním rámci nereflexivních sloves při reciprocitě nominativního ACT a dativního ADDR popisuje pravidlo G23, ACT(1)-ADDR(3)_nerefl.

Toto pravidlo se uplatní i u sloves, která se vyznačují fakultativním reflexivem si, a to v případech, kdy toto reflexivum není u slovesa přítomno; je-li reflexivum si přítomno, uplatňuje se pravidlo G24, ACT(1)-ADDR(3)_refl, viz odd. 3.1.2.1b.

Reciprocita ACT1-ADDR3 | Pravidlo G23
Doplňkové pravidlo, ACT1-ADDR3, nereflexivní | ACT(1)-ADDR(3)_nerefl
podmínky | recipr: ACT-ADDR ADDR3 & ¬SE|SI
ADDR | ✱ → si, sobě
obligatornost | ADDR
zdůraznění | navzájem, vzájemně a/nebo mezi sebou

Pravidlo G23, ACT(1)-ADDR(3)_nerefl, určuje, že v povrchověsyntaktické struktuře recipročních konstrukcí je nutná přítomnost reflexivního osobního zájmena vyjádřeného dativem si / sobě; v případě, že sloveso kromě dativu připouští i další formy vyjádření ADDR, jsou tyto formy pravidlem odstraněny, viz příklad (125).

Volba krátké (klitické) či dlouhé formy reflexivního zájmena je dána zejména faktory souvisejícími s aktuálním členěním (vyjádřeným především slovosledem a prozódií, Daneš et al., 1987; Hajičová, 2007).

1. (122) děkovatimpf ACT1 ADDR3 PATza+4, že MEANStyp7

   ADDR3 → si, sobě Na konci si politikové připili skleničkou šampaňského a navzájem si děkovali za odvedenou práci.

2. (123) představovatimpf — představitpf ACT1 ADDRopt3 PAT4

   ADDR3 → si, sobě Mladí tanečníci … se sejdou, aby představili veřejnosti i sobě vzájemně výsledky své činnosti.

3. (124) darovatpf ACT1 ADDR3 PAT4 CAUStypk+3 AIMtypna+4 RCMPtypza+4

   ADDR3 → si, sobě Ty si pak radní darovali mezi sebou…

4. (125) přehazovatimpf — přehoditpf2 ACT1 ADDR3, na+4 PAT4

   ADDR3, na+4 → si, sobě Obtížné úkoly si mezi sebou přehazují.

Hodnocení formy mezi sebou jako zdůrazňovacího výrazu:
Reflexivní osobní zájmeno ve formě předložkové skupiny mezi sebou zde nepokládáme za realizaci ADDR, neboť tato forma neodpovídá formě daného doplnění ve valenčním rámci slovesa popisujícím nereciproční konstrukci. V doplňkových pravidlech ji proto uvádíme mezi výrazy zdůrazňujícími reciproční význam. Typicky se tato předložková skupina může objevit (podobně jako zdůrazňující adverbia navzájem, vzájemně) v recipročních konstrukcích téměř všech sloves, viz např. (124) nebo (125).

Homonymie reciproční a reflexivní konstrukce:
V případě, že lexikální jednotka slovesa kromě reciprocity nominativního ACT a dativního ADDR umožňuje též syntaktickou reflexivitu typu coref3, mohou na základě pravidla G23, ACT(1)-ADDR(3)_nerefl, vznikat konstrukce, které jsou homonymní s konstrukcemi reflexivními, viz kapitolu 2. Pro odstranění nežádoucí homonymie je v těchto případech nutná přítomnost adverbií navzájem, vzájemně nebo reflexivního osobního zájmena vyjádřeného předložkovou skupinou mezi sebou.

1. (126) namlouvatimpf — namluvitpf ACT1 ADDR3 PAT4, že, cont

   A neustále lžou a něco si namlouvají.

   (struktura je buď reciproční (ve smyslu namlouvají si něco vzájemně), nebo reflexivní (ve smyslu oni namlouvají něco sami sobě))

   Asi proto si tam na sjezdovkách užíváme tak maximálně tři dny a potom si společně všichni navzájem namlouváme, že to byl určitě celý týden.

   (příslovce navzájem vyjadřující reciproční význam homonymii odstraňuje)

   O zakázaných knihách se vůbec nedá mluvit, to si jen tak lidé mezi sebou namlouvají!

   (výraz mezi sebou zjednoznačňuje reciproční význam konstrukce)

2. (127) lhátimpf ACT1 ADDRopt3 PATopto+6, že, cont

   Nejdůležitější je, že si nelžeme.

   (struktura je buď reciproční (ve smyslu lžeme si navzájem), nebo reflexivní (ve smyslu lžeme sami sobě))

   … a tu podivnou domácnost otce a syna, kteří si vzájemně lhali ze samého strachu, aby si neublížili.

   (příslovce s recipročním významem vzájemně reflexivní význam vylučuje)

##### 3.1.2.1b Reciprocita reflexivních sloves s dativním Adresátem.

Reciprocitu nominativního ACT a dativního ADDR vykazují též slovesa reflexivní, a to jak reflexiva tantum (např. chlubit seimpf, postěžovat sipf), tak reflexivní slovesa odvozená (např. svěřovat seimpf — svěřit sepf, psát (si)impf). Změny ve valenčním rámci charakterizující daný typ reciprocity zachycuje pravidlo G24, ACT(1)-ADDR(3)_refl.

Reciprocita ACT1-ADDR3 | Pravidlo G24
Doplňkové pravidlo, ACT1-ADDR3, reflexivní | ACT(1)-ADDR(3)_refl
podmínky | recipr: ACT-ADDR ADDR3 & SE|SI
ADDR | ✱ → sobě, ∅
obligatornost | ADDR má-li ADDR nulovou formu, je reciprocita obligatorně vyjádřena zdůrazňovacím výrazem (či jejich kombinací)
zdůraznění | navzájem, vzájemně a/nebo mezi sebou 3-36

V recipročních konstrukcích těchto reflexivních sloves je na povrchu obligatorně vyjádřen buď dlouhý tvar reflexivního osobního zájmena v dativu sobě, nebo má-li ADDR nulovou formu, některý ze zdůrazňovacích výrazů navzájem, vzájemně či mezi sebou, příp. jejich kombinace, viz např. (129) a druhý příklad (130).

1. (128) stěžovat siimpf ACT1 ADDR3 PATna+4, že, cont

   ADDR3 → sobě "Ty výkyvy teplot, kdy je patnáct stupňů a na druhý den o deset až patnáct více, mi nedělají dobře," stěžují si sobě lidé na potkání.

2. (129) postěžovat sipf ACT1 ADDRopt3 PATna+4, že, cont

   ADDR3 → ∅ A pak jsme si navzájem postěžovaly, čím nás naši drazí manžílkové po ránu naštvali a od tohoto okamžiku jsme k sobě měly hodně blízko.

   (ADDR má nulovou formu, reciproční význam je vyjádřen adverbiem navzájem)

3. (130) svěřovat seimpf — svěřit sepf ACT1 ADDR3 PATopts+7, zda, že, cont

   ADDR3 → sobě Vyříkali si to a zůstali kamarády, kteří se sobě navzájem svěřují.

   (ADDR je vyjádřen reflexivním osobním zájmenem sobě, adverbium navzájem reciproční význam pouze zdůrazňuje)

   ADDR3 → ∅ Nepřipadá vám někdy, že se vaše dcery mezi sebou svěřují…

   (ADDR má nulovou formu, reciproční význam vyjadřuje předložková skupina mezi sebou)

Haplologie reflexiv:
Zdrojem odlišností v chování reflexivních a nereflexivních sloves při reciprocitě nominativního ACT a dativního ADDR je haplologie reflexiv (Rosen, 2014). V případě daného typu reciprocity lze předpokládat, že v reciproční konstrukci reflexivních sloves dochází ke splynutí reflexiva zastupujícího klitický tvar reflexivního osobního zájmena v dativu (vyjadřujícího ADDR) a reflexiva tvořícího součást slovesného lemmatu; viz výše příklad (129) a druhý příklad (130), kde předpokládáme splynutí klitického tvaru reflexivního zájmena osobního s reflexivem si, resp. se, představujícím součást lemmatu slovesa. Pro vyjádření recipročního významu je tak v těchto případech nutná přítomnost adverbií navzájem, vzájemně nebo výrazu mezi sebou.

Slovesa s fakultativním reflexivem si:
U těchto sloves3-37 předpokládáme, že se (v závislosti na přítomnosti reflexiva si) uplatní buď doplňkové pravidlo G23, ACT(1)-ADDR(3)_nerefl, nebo doplňkové pravidlo G24, ACT(1)-ADDR(3)_refl.

1. (131) psát (si)impf ACT1 ADDRopt3 PATo+4, aby, ať, zda DIR3typ

   psát: ADDR3 → si, sobě Psali si o vzorové zkoušky. Napřed psali sobě vzájemně, potom i ostatním.

   (pravidlo G23: v povrchověsyntaktické struktuře reciproční konstrukce je obligatorně přítomen ADDR vyjádřený dativním reflexivním osobním zájmenem)

   psát si: ADDR3 → sobě Psali si o vzorové zkoušky sobě (vzájemně), potom i ostatním.

   (pravidlo G24: v povrchověsyntaktické struktuře reciproční konstrukce je obligatorně přítomen ADDR vyjádřený dlouhým tvarem reflexivního osobního zájmena v dativu)

   psát si: ADDR3 → ∅ Psali si navzájem o vzorové zkoušky.

   (pravidlo G24: v povrchověsyntaktické struktuře reciproční konstrukce má ADDR nulovou formu, vyjádření recipročního významu je zde podmíněno přítomností adverbia navzájem)

   psát si: ADDR3 → sobě Psali si sobě navzájem o vzorové zkoušky.

   (pravidlo G24: v povrchověsyntaktické struktuře reciproční konstrukce je ADDR vyjádřen dlouhým tvarem reflexivního osobního zájmena v dativu, adverbium navzájem zde slouží ke zdůraznění recipročního významu)

Homonymie reciproční a reflexivní konstrukce:
Ve slovníku VALLEX nebylo nalezeno žádné reflexivní sloveso s daným typem reciprocity, které by zároveň umožňovalo syntaktickou reflexivitu typu coref3.3-38 Reciproční konstrukce, které vznikají na základě pravidla G24, ACT(1)-ADDR(3)_refl, tedy nepokládáme za homonymní s konstrukcemi reflexivními.

#### 3.1.2.2 Reciprocita nominativního Konatele a akuzativního Adresátu

Reciprocita nominativního Konatele (ACT) a akuzativního Adresátu (ADDR) je ve slovníku VALLEX doložena pouze u nereflexivních sloves, u nichž je akuzativ jedinou možnou formou Adresátu. Uvedený typ reciprocity zachycuje jediné doplňkové pravidlo G25, ACT(1)-ADDR(4)_nerefl.

Reciprocita ACT1-ADDR4 | Pravidlo G25
Doplňkové pravidlo ACT1-ADDR4 nereflexivní | ACT(1)-ADDR(4)_nerefl
podmínky | recipr: ACT-ADDR ADDR4 & ¬SE|SI
ADDR | ✱ → se, sebe
obligatornost | ADDR
zdůraznění | navzájem, vzájemně a/nebo mezi sebou 3-39

Pravidlo G25, ACT(1)-ADDR(4)_nerefl, stanoví, že v povrchověsyntaktické struktuře recipročních konstrukcí je obligatorně přítomen ADDR vyjádřený reflexivním osobním zájmenem se / sebe. Volba krátké (klitické) či dlouhé formy reflexivního zájmena je dána zejména faktory souvisejícími s aktuálním členěním (vyjádřeným především slovosledem a prozódií, Daneš et al., 1987; Hajičová, 2007).

1. (132) prositimpf ACT1 ADDR4 PATo+4, za+4, inf, aby, ať

   ADDR4 → se, sebe Bratři se navzájem prosí za odpuštění.

2. (133) naříkatIIimpf — nařknoutpf ACT1 ADDR4 PATz+2, že

   ADDR4 → se, sebe Ztráty ale radnice nedokázala přesně vyčíslit, nejdříve žádala dva miliony, později skoro šest a půl milionu korun. Zároveň také M-Beta tvrdila, že to je naopak ona, která utrpěla ztráty a město jí dluží. Obě strany se nařkly z nepořádku v účetnictví.

3. (134) informovatbiasp ACT1 ADDR4 PATo+6

   ADDR4 → se, sebe Smyslem setkání je informovat starosty i sebe navzájem o novinkách v knihovnictví.

Reciproční význam může být zvýrazněn adverbii navzájem, vzájemně nebo reflexivním osobním zájmenem vyjádřeným předložkovou skupinou mezi sebou.

1. (135) okrádatimpf — okrástpf ACT1 ADDR4 PATopto+4 REGtypna+6

   Podle policistů není vyloučeno, že v těchto případech se autodopravci okrádají navzájem.

2. (136) nutitimpf ACT1 ADDR4 PATdo+2, k+3, inf, aby, ať MEANStyp7

   … já vidím lidi, kteří se vzájemně nutí pokleknout a vyjadřovat nadšení, rozkoš, obdiv.

3. (137) informovatbiasp ACT1 ADDR4 PATaby, ať, zda, že, cont

   Devátá základní škola praská kvůli počtu žáků ve švech, neboť rodiče dyslektických dětí se mezi sebou informují, která škola je pro jejich děti dobrá a proč.

Homonymie reciproční a reflexivní konstrukce:
V případě, že sloveso kromě reciprocity nominativního ACT a akuzativního ADDR umožňuje též syntaktickou reflexivitu typu coref4, mohou na základě pravidla G25, ACT(1)-ADDR(4)_nerefl, vznikat konstrukce, které jsou homonymní s konstrukcemi reflexivními. Pro odstranění nežádoucí homonymie je nutné užití některého z výrazů zdůrazňujících reciproční pojetí děje, tedy navzájem, vzájemně nebo mezi sebou.

1. (138) obviňovatimpf — obvinitpf ACT1 ADDR4 PATz+2, že

   … sledují víc než nesmyslné slovní šarvátky tří neurotiků, kteří se neustále z něčeho obviňují.

   (konstrukci lze interpretovat buď jako reciproční (ve smyslu tři neurotici se obviňují vzájemně), nebo jako reflexivní (ve smyslu tři neurotici obviňují každý sám sebe))

2. (139) nutitimpf ACT1 ADDR4 PATdo+2, k+3, inf, aby, ať MEANStyp7

   Jíru a Ziku nabádáme, aby si s pukem zbytečně nehráli, ale nutili se do střelby.

   (struktura má buď význam reciproční (ve smyslu nabádali jsme Jíru a Zíku, aby se vzájemně nutili do střelby), nebo význam reflexivní (ve smyslu nabádali jsme Jíru a Zíku, aby sami sebe nutili do střelby))

3. (140) přesvědčovatimpf — přesvědčitpf ACT1 ADDR4 PATk+3, o+6, inf, aby, ať, že, cont MEANStyp7

   Tak dlouho jsme se navzájem přesvědčovali, že soužití psa s člověkem je ideální, až přišlo vystřízlivění.

   Věděli, že spolu mohou být jen měsíc, a až do konce se vzájemně přesvědčovali, že je to tolik nemrzí.

   (reflexivní význam je přítomností adverbií s recipročním významem navzájem a vzájemně blokován)

#### 3.1.2.3 Reciprocita nominativního Konatele a genitivního Adresátu

Reciprocita nominativního ACT a genitivního ADDR se ve slovníku VALLEX vyskytuje pouze u sloves tázání ptát seimpf, tázat seimpf, otázat sepf, vyptávat seimpf — vyptat sepf, zeptat sepf, která představují reflexiva tantum; u těchto sloves je genitiv jedinou možnou formou vyjádření Adresátu. Daný typ reciprocity popisuje doplňkové pravidlo G26, ACT(1)-ADDR(2)_refl.

Reciprocita ACT1-ADDR2 | Pravidlo G26
Doplňkové pravidlo ACT1-ADDR2 reflexivní | ACT(1)-ADDR(2)_refl
podmínky | recipr: ACT-ADDR ADDR2 & SE
ADDR | ✱ → sebe, ∅
obligatornost | ADDR má-li ADDR nulovou formu, je reciprocita obligatorně vyjádřena zdůrazňovacím výrazem
zdůraznění | navzájem, vzájemně a/nebo mezi sebou 3-40

Pravidlo G26, ACT(1)-ADDR(2)_refl, určuje, že v povrchověsyntaktické struktuře těchto recipročních konstrukcí je buď přítomno reflexivní osobní zájmeno vyjádřené v genitivu (viz (141), první příkladová věta), nebo má-li ADDR nulovou formu, zdůrazňovací výraz (druhá příkladová věta (141), třetí a čtvrtá věta (142)).3-41

1. (141) zeptat sepf ACT1 ADDR2 PATna+4, zda, cont MANNtyp

   ADDR2 → sebe … možná již přišel čas se zastavit a zeptat se sebe navzájem, zda neděláme chybu.

   ADDR2 → ∅ Vytváří se skupiny lidí, kteří si ráno zavolají, zeptají se vzájemně na zdraví, zjistí, co kdo potřebuje, a popřejí si hezký den.

Homonymie reciproční a reflexivní konstrukce:
V případě, že sloveso s genitivním Adresátem kromě reciprocity umožňuje i syntaktickou reflexivitu,3-42 mohou na základě pravidla G26, ACT(1)-ADDR(2)_refl, vznikat konstrukce, které jsou homonymní s konstrukcemi reflexivními. Nežádoucí homonymie je odstraněna adverbii navzájem, vzájemně nebo výrazem mezi sebou, případně jejich kombinací.

1. (142) ptát seimpf ACT1 ADDR2 PATna+4, zda, cont MANNtyp

   Kolikrát jsme se ptali sebe a druhých, proč se to stalo právě nám?

   (konstrukci lze vykládat jako reciproční (ve smyslu ptali jsme se sebe navzájem), nebo jako reflexivní (ve smyslu ptali jsme se sami sebe))

   Když se shromážděný dav na Petrském náměstí v Římě 16. října 1978 dověděl, že novým papežem se stal polský arcibiskup Karol Wojtyla, ptali se lidé sebe navzájem: Kdo to je?

   Kolikrát jsme se ptali navzájem, proč se to stalo právě nám?

   Voláme si, ptáme se vzájemně, jak se vede.

   (přítomnost adverbií navzájem a vzájemně s recipročním významem homonymii vylučuje)

#### 3.1.2.4 Reciprocita nominativního Konatele a Adresátu vyjádřeného předložkovou skupinou s+7

Chování nereflexivních i reflexivních sloves s reciprocitou nominativního ACT a ADDR vyjádřeného předložkovou skupinou s+7 popisuje doplňkové pravidlo G27, ACT(1)&ndash;ADDR(s+7). Řada sloves, jejichž reciproční konstrukce popisuje toto pravidlo, představuje inherentní reciproka a dále reciproka odvozená, kde základová slovesa rys inherentní reciprocity ve svém lexikálním významu sice nenesou, odvozená slovesa ale tento rys získávají (viz odd. GUIDE > 4.4, typ A a B).3-43

Reciprocita ACT1-ADDRs+7 | Pravidlo G27
Doplňkové pravidlo ACT1-ADDRs+7 | ACT(1)-ADDR(s+7)
podmínky | recipr: ACT-ADDR ADDRs+7
ADDR | ✱ → ∅
zdůraznění | spolu a/nebo navzájem, vzájemně a/nebo mezi sebou 3-44

Pravidlo G27, ACT(1)-ADDR(s+7), specifikuje, že ADDR má v reciproční konstrukci nulovou formu, tj. není na povrchu vyjádřen. V případě, že sloveso umožňuje vyjádření ADDR i jinou formou než předložkovou skupinou s+7, jsou tyto formy pravidlem odstraněny (146).

1. (143) spolupracovatimpf ACT1 ADDRs+7 PAToptna+6, v+6 LOCtyp

   ADDRs+7 → ∅ Ti tento nález považují za jeden z nejdůležitějších důkazů toho, že obrovští masožraví dinosauři spolupracovali při lovu, tak jako například lvi.

2. (144) poprat sepf ACT1 ADDRs+7 PATopto+4

   ADDRs+7 → ∅ Čtyři kluby se poperou o poslední postupové místo v play off.

3. (145) vyjasňovat siimpf — vyjasnit sipf ACT1 ADDRs+7 PAT4, zda, že, cont

   ADDRs+7 → ∅ Ve čtvrtek si vzájemně vyjasňovali v Jeruzalémě pozice Peres se zvláštním vyslancem USA pro Blízký východ Georgem J. Mitchellem.

   (předložková skupina s+7 je součástí hypotaktické koordinace, kterou je vyjádřen ACT)

4. (146) bojovatimpf ACT1 ADDRproti+3, s+7 PATopt4 EFFopto+4

   ADDRproti+3, s+7 → ∅ Druhý největší světový ocelářský koncern LNM Group a největší americké ocelárny US Steel spolu bojují o ovládnutí východoevropského trhu.

Reciproční význam může být zdůrazněn adverbii spolu, navzájem, vzájemně nebo reflexivním osobním zájmenem vyjádřeným předložkovou skupinou mezi sebou, příp. jejich kombinací.

1. (147) vyjednávatimpf — vyjednatpf ACT1 ADDRs+7 PAT4, zda, že, cont

   Mírovou smlouvu spolu vyjednali nacionalisté všech tří stran.

2. (148) vyměňovatimpf — vyměnitpf ACT1 ADDRs+7 PAT4 EFFza+4 BENtyp3, pro+4

   Poslanci tvořili hloučky a navzájem si vyměňovali informace o postojích toho či toho…

3. (149) soupeřitimpf ACT1 ADDRproti+3, s+7 PATopto+4 REGtypv+6

   Očekává, že lidi spolu navzájem soupeří ve prospěch svých vlastních zájmů…

Homonymie reciproční konstrukce a konstrukce s nevyjádřeným ADDR:
Reciproční konstrukce sloves s reciprocitou nominativního ACT a ADDR vyjádřeného předložkovou skupinou s+7 mohou vykazovat homonymii s konstrukcemi nerecipročními s povrchově nevyjádřeným ADDR. Nežádoucí homonymii zamezuje přítomnost adverbií spolu, vzájemně, navzájem nebo předložkové skupiny mezi sebou v povrchověsyntaktické struktuře. Tři posledně zmíněné výrazy se často kombinují s adverbiem spolu (spolu vzájemně, spolu navzájem a spolu mezi sebou).

1. (150) komunikovatimpf ACT1 ADDRs+7 PATopto+6 MANNtyp

   Musí to být hráči, kteří komunikují a dokážou mužstvu pomoci, když se nedaří.

   (struktura má buď reciproční význam (ve smyslu musí to být hráči, kteří spolu navzájem komunikují), nebo jde o nereciproční význam s povrchově nevyjádřeným ADDR (ve smyslu musí to být hráči, kteří dokážou komunikovat s každým, s kým je třeba))

   Hlídky navzájem komunikují v angličtině a němčině.

   Společnosti sice mezi sebou komunikují telefonicky, faxem či e-mailem, ale navzájem si nenarušují svoje kompetence.

   (přítomnost adverbia navzájem a výrazu mezi sebou zamezuje nežádoucí homonymii)

#### 3.1.2.5 Reciprocita nominativního Konatele a Adresátu vyjádřeného ostatními předložkovými skupinami

Následující pravidlo G28, ACT(1)-ADDR(prep), popisuje chování nereflexivních i reflexivních sloves při reciprocitě nominativního ACT a ADDR vyjádřeného jednou z uvedených předložkových skupin k+3, mezi+4, na+4, na+6, proti+3, před+4 a před+7.

Reciprocita ACT1-ADDRprep | Pravidlo G28
Doplňkové pravidlo ACT1-ADDRprep | ACT(1)-ADDR(prep)
podmínky | recipr: ACT-ADDR ADDRk+3, mezi+4, na+4, na+6, proti+3, před+4, před+7
ADDR | k+3 → k sobě
| mezi+4 → mezi sebe
| na+4 → na sebe
| na+6 → na sobě
| proti+3 → proti sobě
| před+4 → před sebe
| před+7 → před sebou
| ostatní formy → ∅
obligatornost | ADDR
zdůraznění | vzájemně, navzájem

Pravidlo G28, ACT(1)-ADDR(prep), určuje, že v povrchověsyntaktické struktuře reciproční konstrukce je ADDR vyjádřen reflexivním osobním zájmenem, které má formu předložkové skupiny dané v rámci popisujícím nereciproční konstrukci. V případě, že sloveso umožňuje ADDR vyjádřit i jinými formami, jsou tyto formy pravidlem odstraněny, viz příklady (152) a (155).

1. (151) promlouvatimpf — promluvitpf ACT1 ADDRoptk+3 PATopto+6

   ADDRk+3 → k sobě Vždyť i po tolika letech společného života se drží za ruce a láskyplně k sobě promlouvají.

2. (152) dělitimpf ACT1 ADDRopt3, mezi+4 PAT4 EFFdo+2, na+4 MEANStyp7 BENtyp3, pro+4

   ADDR3, mezi+4 → mezi sebe Když kdysi v barbarských dobách dělili mezi sebe synové norského panovníka království… 3-45 , 3-46

3. (153) cenitIIimpf ACT1 ADDRoptna+4 PAT4

   ADDRna+4 → na sebe Jako první na sebe zřejmě vesele cenili zuby naši opičí bratranci.

4. (154) dopouštětI seimpf — dopustitI sepf ACT1 ADDRoptna+6 PAT2

   ADDRna+6 → na sobě Oba národy […] přiznávají bezpráví, kterého se v minulosti na sobě navzájem dopustily.

5. (155) soutěžitimpf ACT1 ADDRproti+3, s+7 PATopto+4 REGtypv+6

   ADDRproti+3, s+7 → proti sobě Obě školy proti sobě soutěžily ve střelbě kuší.

6. (156) stavětIimpf ACT1 ADDRpřed+4 PAT4

   ADDRpřed+4 → před sebe Nemá smysl vzájemně před sebe stavět nějaké cíle. [příklad vlastní]

7. (157) skrývatimpf — skrýtpf ACT1 ADDRoptpřed+7 PAT4, že, cont BENtyp3, pro+4 LOCtyp DIR3typ

   ADDRpřed+7 → před sebou Děti mají v tomto směru naprostou volnost, nic před sebou neskrýváme.

Reciproční význam může být zdůrazněn adverbii vzájemně nebo navzájem.

1. (158) bojovatimpf ACT1 ADDRproti+3, s+7 PATopt4 EFFopto+4

   Síly i prostředky, jimiž dosud vzájemně podniky proti sobě bojovaly, mohou býti zužitkovány nyní účelněji.

2. (159) obracet seimpf — obrátit sepf ACT1 ADDRk+3, na+4 PATopto+4, s+7 REGtypv+6

   Nepochybně se na sebe navzájem obracíme i ve chvílích, kdy nám třeba není úplně nejlíp.

Homonymie reciproční a reflexivní konstrukce:
V případě, že sloveso s Adresátem vyjádřeným předložkovou skupinou umožňuje kromě reciprocity i syntaktickou reflexivitu,3-47 mohou na základě pravidla G28, ACT(1)-ADDR(prep), vznikat konstrukce, které jsou homonymní s konstrukcemi reflexivními. Nežádoucí homonymie je odstraněna adverbii navzájem nebo vzájemně.

1. (160) stavětIimpf ACT1 ADDRpřed+4 PAT4

   ADDRpřed+4 → před sebe Byli jsme silní a neustále jsme si před sebe stavěli možné datum osvobození.

   (konstrukci lze vykládat jako reciproční (ve smyslu navzájem jsme před sebe stavěli možné datum osvobození), nebo jako reflexivní (ve smyslu stavěli jsme sami před sebe možné datum osvobození))

## 3.2 Reciprocita Patientu a Efektu

Zopakujme zde, že při reciprocitě Patientu (PAT) a Efektu (EFF) jak PAT, tak EFF odpovídají oběma situačním participantům ve vztahu symetrie. Ve VALLEXu má u těchto lexikálních jednotek PAT formu přímého objektu (který tak odpovídá oběma zasaženým participantům); důsledkem této korespondence je, že objekt je typicky obsazen substantivy vyjádřenými v plurálu, substantivy koordinovanými paratakticky nebo hypotakticky, příp. jde o jména formálně vyjádřená singulárem, ale s významem plurálovým, o tzv. kolektiva, viz Mluvnici češtiny 2 (Komárek et al., 1986). Pozice EFF je často v povrchověsyntaktické konstrukci nevyjádřena, případně může být fakultativně vyjádřena reflexivním zájmenem v předložkovém tvaru (daném formou doplnění ve valenčním rámci popisujícím nereciproční užití).

Reciprocita PAT-EFF je v datové komponentě slovníku zachycena hodnotou atributu recipr: ACT-ADDR. Pro odvození reciproční konstrukce je třeba na valenční rámec zachycený v datové komponentě slovníku, který odpovídá nerecipročnímu užití,3-48 aplikovat:

- nejprve základní pravidlo G29, viz odd. 3.2.1, popisující změny v morfematickém vyjádření PAT;

- a poté (v závislosti na podmínkách kladených na podobu EFF) právě jedno z doplňkových pravidel uvedených v odd. 3.2.2; tato pravidla popisují změny v morfematickém vyjádření Efektu (EFF) a zachycují, jakými výrazy je možné reciproční pojetí děje zdůraznit.

Některá slovesa charakterizuje více možností, jak v recipročních konstrukcích vyjádřit EFF; v takových případech se aplikují všechny přípustné dvojice základní pravidlo – doplňkové pravidlo.

### 3.2.1 Základní pravidlo

Základní pravidlo G29, recipr_obj_basic, popisuje změny společné všem lexikálním jednotkám sloves, které umožňují reciprocitu akuzativního Patientu (PAT) a Efektu (EFF) vyjádřeného různými morfematickými formami.3-49

Reciprocita PAT-EFF | Pravidlo G29
Pravidlo (změna formy doplnění) | recipr_obj_basic
podmínky | recipr: PAT-EFF PAT4
PAT | 4 → 4:plurál

Podmínka PAT4:
Možnost vyjádřit Patiens (PAT) akuzativem je společná všem lexikálním jednotkám ve slovníku VALLEX, které vykazují reciprocitu typu PAT-EFF. U všech těchto sloves je akuzativ jedinou možnou formou PAT a tento PAT je vždy obligatorní.

Forma slovesa, shoda:
Sloveso je v reciproční konstrukci (stejně jako v konstrukci nereciproční) aktivního rodu; reciprocita nezasahuje subjekt, pravidlo proto nemění shodu.

### 3.2.2 Doplňková pravidla

Valenční doplnění EFF typicky může být v recipročních konstrukcích vyjádřeno reflexivním osobním zájmenem v morfematickém tvaru daném valenčním rámcem pro nereciproční užití, často má však nulovou formu (tj. není na povrchu vyjádřeno). Doplňková pravidla popisují změny ve vyjádření EFF a dále zachycují, jakými výrazy je možné zdůraznit reciproční pojetí děje.

Následující tabulka podává základní přehled forem reflexivního osobního zájmena v recipročních konstrukcích s reciprocitou typu PAT-EFF, podrobnou analýzu zachycují až uvedená pravidla.

TABLE!

#### 3.2.2.1 Reciprocita akuzativního Patientu a Efektu vyjádřeného předložkovou skupinou s+7

Reciprocita PAT4-EFFs+7 | Pravidlo G30
Doplňkové pravidlo PAT4-EFFs+7 | PAT(4)-EFF(s+7)
podmínky | recipr: PAT-EFF EFFs+7
EFF | ✱ → ∅
zdůraznění | spolu, dohromady, navzájem, vzájemně (příp. jejich kombinace)

Vyjádření EFF:
Pravidlo G30, PAT(4)-EFF(s+7), určuje, že EFF realizovaný ve valenčním rámci odpovídajícím nereciproční konstrukci předložkovou skupinou s+7 má v reciproční konstrukci nulovou formu, tj. není v povrchověsyntaktické struktuře vyjádřen. Pokud může být EFF realizován i jinými formami než danou předložkovou skupinou, jsou tyto formy pravidlem odstraněny.

1. (161) kombinovatimpf ACT1 PAT4 EFFs+7

   EFFs+7 → ∅ Dobřanská kapela Layla, která ve své hudbě kombinuje rock, funky a jazz, potěší své plzeňské fanoušky opět 13. května.

2. (162) srovnávatimpf — srovnatpf ACT1 PAT4 EFFs+7

   EFFs+7 → ∅ Srovnáme-li například tvůrčí počátky Kraskovy a Hlaváčkovy…

3. (163) střídatimpf ACT1 PAT4 EFF7, s+7, za+4

   EFF7, s+7, za+4 → ∅ [Jsou Lužičtí Srbové pouhá národnostní menšina?] Mnohokrát denně střídají oba tyto nepodobné jazyky.

Pro zdůraznění recipročního významu může být v recipročních konstrukcích užito adverbií spolu, dohromady, navzájem nebo vzájemně, příp. jejich kombinace.

1. (164) kombinovatimpf ACT1 PAT4 EFFs+7

   Lékaři varují ještě před jedním: nekombinujte spolu různé druhy kapek a léků na kašel.

   K dosažení vyššího účinku je někdy výhodné vzájemně kombinovat léky různého chemického složení a různého mechanismu působení.

2. (165) plést (si)impf ACT1 PAT4 EFFs+7

   Pletou všechny výrazy dohromady.

3. (166) porovnávatimpf — porovnatpf ACT1 PAT4 EFFs+7

   Bude to tedy možné zjistit až po prázdninách, když navzájem porovnáme statistiky za letošní a loňský rok.

#### 3.2.2.2 Reciprocita akuzativního Patientu a Efektu vyjádřeného předložkovou skupinou za+4

Pravidlo G31, PAT(4)-EFF(za+4), popisuje změny ve vyjádření EFF vyjádřeného v nepříznakové konstrukci předložkovou skupinou za+4.

Reciprocita PAT4-EFFza+4 | Pravidlo G31
Doplňkové pravidlo PAT4-EFFza+4 | PAT(4)-EFF(za+4)
podmínky | recipr: PAT-EFF EFFza+4
EFF | ✱ → za sebe, ∅
zdůraznění | navzájem, vzájemně (příp. jejich kombinace)

Vyjádření EFF:
Pravidlo G31, PAT(4)-EFF(za+4), stanoví, že EFF realizovaný ve valenčním rámci odpovídajícím nereciproční konstrukci předložkovou skupinou za+4 je v reciproční konstrukci vyjádřen reflexivním zájmenem ve formě dané předložkové skupiny, tedy za sebe,3-50 příp. má nulovou formu (tj. není na povrchu vyjádřen). Pokud může být EFF realizován i jinými formami než danou předložkovou skupinou, jsou tyto formy pravidlem odstraněny.

1. (167) měnitimpf ACT1 ADDRs+7 PAT4 EFFza+4 BENtyp3, pro+4

   EFFza+4 → ∅ Když mi bylo deset, pořád jsme s klukama měnili známky.

2. (168) vystřídatpf ACT1 PAT4 EFF7, s+7, za+4

   EFF7, s+7, za+4 → ∅ Od deseti čtyřiceti do půlnoci byl na parketu, vystřídal řadu tanečnic, víceméně ho všichni viděli.

Pro zdůraznění recipročního významu může být v recipročních konstrukcích užito adverbií navzájem nebo vzájemně.

1. (169) nahrazovatimpf — nahraditpf ACT1 PAT4 EFF7, za+4 BENtyp3

   Ceny plynu jsou ve světě s cenami ropy a ropných produktů provázány, protože se komodity mohou na trhu s energií navzájem nahrazovat.

2. (170) vyměňovatimpf — vyměnitpf ACT1 ADDRs+7 PAT4 EFFza+4 BENtyp3, pro+4

   Vůbec nejhladší může být pokus vyměnit vzájemně dva byty, které patří obci.

#### 3.2.2.3 Reciprocita akuzativního Patientu a Efektu vyjádřeného předložkovou skupinou k+3

Pravidlo G32, PAT(4)-EFF(k+3), se vztahuje k lexikálním jednotkám sloves umožňujícím reciprocitu PAT a EFF, u nichž je EFF vyjádřen předložkovou skupinou k+3.

Reciprocita PAT4-EFFk+3 | Pravidlo G32
Doplňkové pravidlo PAT4-EFFk+3 | PAT(4)-EFF(k+3)
podmínky | recipr: PAT-EFF EFFk+3
EFF | ✱ → k sobě, ∅
zdůraznění | dohromady, navzájem, vzájemně

Pravidlo G32, PAT(4)-EFF(k+3), určuje, že EFF je v povrchověsyntaktické struktuře vyjádřen buď reflexivním osobním zájmenem realizovaným předložkovou skupinou k sobě, nebo má nulovou formu, tj. není na povrchu vyjádřen. Pokud může být EFF vyjádřen i jinými formami než danou předložkovou skupinou, jsou tyto formy pravidlem odstraněny.

1. (171) přirovnávatimpf — přirovnatpf ACT1 PAT4 EFFk+3

   EFFk+3 → k sobě Oba astrology jsme k sobě přirovnali, protože toho mají dost společného.

2. (172) poutatimpf ACT1 PAT4 EFFoptk+3, na+4, s+7 MEANStyp7 BENtyp3

   EFFk+3, na+4, s+7 → k sobě … nás k sobě nepoutala žádná vášeň…

   EFFk+3, na+4, s+7 → ∅ Nás dva ale poutaly pásky od kalhot.

3. (173) přiřazovat / přiřaďovatimpf — přiřaditpf ACT1 PAT4 EFFk+3

   EFFk+3 → ∅ Zjistilo se, že jsme schopni přiřazovat slova rychleji.

Pro zdůraznění recipročního významu mohou být v recipročních konstrukcích daného typu užita adverbia dohromady, navzájem nebo vzájemně.

1. (174) připoutávatimpf — připoutatpf ACT1 PAT4 EFFk+3, na+4 MEANStyp7 LOCtyp

   Nakonec je ale podobná trápení přirozeně připoutají dohromady.

2. (175) poutatimpf ACT1 PAT4 EFFoptk+3, na+4, s+7 MEANStyp7 BENtyp3

   Molekula se skládá ze dvou nebo více atomů buď téhož prvku, nebo z atomů různých prvků, které jsou navzájem poutány chemickými vazbami.

   Molekuly první skupiny jsou vzájemně poutány jen fyzikálními vazbami.

#### 3.2.2.4 Reciprocita akuzativního Patientu a Efektu vyjádřeného ostatními předložkovými skupinami

Pravidlo G33, PAT(4)-EFF(na+4,proti+3), popisuje změny ve vyjádření EFF při reciprocitě akuzativního PAT a EFF vyjádřeného předložkovou skupinou na+4 nebo proti+3.

Reciprocita PAT4-EFFna+4, proti+3 | Pravidlo G33
Doplňkové pravidlo PAT4-EFFna+4, proti+3 | PAT(4)-EFF(na+4,proti+3)
podmínky | recipr: PAT-EFF EFFna+4, proti+3
EFF | na+4 → na sebe
| proti+3 → proti sobě
| ostatní formy → ∅
obligatornost | EFF
zdůraznění | navzájem, vzájemně

Pravidlo G33, PAT(4)-EFF(na+4,proti+3), stanoví, že v povrchověsyntaktické struktuře reciproční konstrukce je obligatorně vyjádřeno reflexivní osobní zájmeno realizované příslušnou předložkovou skupinou, tedy na sebe či proti sobě. Pokud může být EFF vyjádřen i jinými formami, jsou tyto formy pravidlem odstraněny. Na rozdíl od reciprocity typu PAT-EFF s EFF vyjádřeným předložkovými skupinami s+7, za+4 či k+3 musí být u tohoto typu reciprocity EFF na povrchu vyjádřen (jinak není reciproční interpretace možná).

1. (176) štvátimpf ACT1 PAT4 EFFproti+3

   EFFproti+3 → proti sobě Neváhali přitom vyrábět i promyšlené provokace, jejichž účelem bylo štvát proti sobě reichswehr a SA.

2. (177) přivazovatimpf — přivázatpf ACT1 PAT4 EFFk+3, na+4 LOCtyp

   EFFk+3, na+4 → na sebe Dřevorubci přivázali klády na sebe. [příklad vlastní]

3. (178) zvykatimpf — zvyknoutpf ACT1 PAT4 EFF3, na+4, inf, aby, ať, že, cont

   EFF3, na+4, inf, aby, ať, že, cont → na sebe V prvním poločase si na sebe hráči zvykali.

Reciproční význam může být u lexikálních jednotek těchto sloves zdůrazněn adverbii navzájem nebo vzájemně.

1. (179) štvátimpf ACT1 PAT4 EFFproti+3

   Nezúčastním se summitu, který rozděluje islám na dvě skupiny a štve proti sobě navzájem šíity a sunnity.

2. (180) zvykatimpf — zvyknoutpf ACT1 PAT4 EFF3, na+4, inf, aby, ať, že, cont

   Náš mladý mančaft si zvyká na druhou ligu mužů, členové týmu si vzájemně zvykají na sebe.

# Lexikalizované alternace

Při formulaci pravidel charakterizujících změny ve valenční struktuře sloves, která vytvářejí syntaktické konstrukce ve vztahu lexikalizované alternace – tedy ve vztahu lexikálněsémantické konverze, rozdílné strukturní realizace téhož situačního participantu a strukturního rozpadu situačního participantu na dvě valenční doplnění – využíváme obecných pravidel určujících změny ve vzájemné korespondenci situačních participantů a valenčních doplnění (Kettnerová, 2014). Konstrukce příslušející dané lexikalizované alternaci označujeme vždy symboly I a II, více viz níže. Změny ve valenčním rámci jsou v případě lexikalizovaných alternací i v rámci jediné sémantické skupiny sloves natolik rozmanité (často zasahují počet, typ (funktor) i obligatornost valenčních doplnění), že je nelze popisovat pomocí formálních syntaktických pravidel tak, jako je tomu u gramatikalizovaných alternací; jsou proto ve VALLEXu zachyceny pomocí samostatných lexikálních jednotek.

Pravidla pro lexikalizované alternace, popisující změny v uspořádání situačních participantů do valenčního rámce, mají následující strukturu:

Typ lexikalizované alternace | Pravidlo
Podtyp dané alternace | Název pravidla
podmínka | Atribut: Hodnota atributu
| I | II
Situační participant | X | Y

I a II: Označení syntaktických konstrukcí ve vztahu lexikální alternace
V pravidle ve sloupci I uvádíme valenční doplnění typická pro syntaktickou konstrukci, kterou lze hodnotit jako sémanticky méně příznakovou. Ve sloupci II pak uvádíme ta doplnění, která jsou charakteristická pro syntaktickou konstrukci sémanticky příznakovou. Jelikož sémantické hodnocení jednotlivých konstrukcí není z hlediska příznakovosti v mnoha případech jednoznačné, je toto řazení do značné míry arbitrární. Tam, kde je lexikalizovaná alternace spojena s možným holistickým efektem, hodnotíme jako sémanticky příznakovou tu syntaktickou konstrukci, která umožňuje holistickou interpretaci.
Například u slovesa vycházetimpf — vyjítpf může být situační participant „Goal“ syntakticky strukturován buď jako volné doplnění typu DIR3, nebo jako aktant PAT. Syntaktické konstrukce, v nichž „Goal“ odpovídá PAT, jsou spojeny s holistickým efektem, jelikož tento participant v nich označuje určitý úsek cesty jako celek, který je zasažený dějem vyjadřovaným slovesem (nikoli pouze cílový bod pohybu, jako je tomu v případě, kdy tento participant koresponduje s volným doplněním DIR3); vyjadřuje tak komplexnější děj (Hovav – Levin, 1988). Syntaktickou konstrukci s aktantem PAT proto označujeme jako sémanticky příznakovou (označení II), zatímco konstrukci, v níž daný participant odpovídá DIR3, chápeme jako sémanticky méně příznakovou (označení I).

X, Y: Funktory
Změny v korespondenci situačních participantů a valenčních doplnění jsou zapsány formou tabulky, kde sloupce I a II obsahují valenční doplnění, označená funktory, se kterými může příslušný situační participant v rámci daného typu alternace v konstrukci I a II korespondovat; zde je označujeme jako X a Y.

X | Y: Varianty funktorů
Umožňuje-li daná alternace v některé ze svých konstrukcí korespondenci situačního participantu s více valenčními doplněními, jsou tato doplnění oddělena pomocí symbolu | (daný situační participant pak může být v konkrétním užití přiřazen právě jednomu z uvedených valenčních doplnění), např. u lexikální jednotky slovesa vyčistitpf s valenčním rámcem ACT1 PAT4 DIR1typ LOCtyp, na kterou se vztahuje pravidlo L3, conv_loc_nonpers2, může být situační participant „Location“ v konstrukci I přiřazen buď doplnění DIR1, např. Jana vyčistila skvrny ze sukně.DIR1., nebo doplnění LOC, např. Jana vyčistila skvrny na sukni.LOC.

∅: Situační participant nekoresponduje s žádným valenčním doplněním
Pokud se ve valenčním rámci příslušné lexikální jednotky slovesa nevyskytuje ani jediné doplnění z variant uvedených v pravidle pro danou konstrukci, platí pro odpovídající participant hodnota ∅; tato hodnota vyznačuje, že daný participant nekoresponduje s žádným valenčním doplněním, a nemůže být tedy ani povrchověsyntakticky vyjádřen, např. u lexikální jednotky slovesa lovitimpf s valenčním rámcem ACT1 PAT4, např. Rybáři lovili rybník., není situační participant „Locatum“ přiřazen žádnému valenčnímu doplnění, a nemůže být tedy vyjádřen ani v povrchověsyntaktické struktuře (viz pravidlo L3, conv_loc_nonpers2).3-51

X & Y: Rozpad situačního participantu na dvě valenční doplnění
Symbol & uvedený v pravidlech spojuje dvojice takových valenčních doplnění, jimž je přiřazen jediný participant, např. u lexikální jednotky slovesa míchatimpf s rámcem ACT1 ADDRs+7 PAT4 EFFdo+2, v+4 odpovídá situační participant „Material“ doplněním ADDR a PAT zároveň, např. Míchejte cukr.PAT s bílkem.ADDR do husté hmoty. (viz pravidlo L5, conv_mat).

Morfematické vyjádření
Vzhledem k tomu, že rozdílným lexikálním jednotkám spojeným některou z lexikalizovaných alternací odpovídají ve slovníkové části odlišné valenční rámce, v nichž je u jednotlivých valenčních doplnění jejich morfematická realizace buď explicitně vyznačena, nebo implicitně vyplývá z typu funktoru, není třeba tyto změny v pravidlech pro lexikalizované alternace zachycovat; povrchověsyntaktické vyjádření valenčních doplnění zasažených příslušnou alternací je zachyceno již ve slovníkové části.

# 4 Lexikálněsémantické konverze

V případě lexikálněsémantické konverze jde o konverzní vztah mezi dvěma lexikálními jednotkami téhož slovesného lexému, u nichž jsou vždy dva situační participanty rozdílným způsobem přiřazeny valenčním doplněním. V důsledku změn v uspořádání situačních participantů do valenčního rámce dochází též ke změnám v jejich povrchověsyntaktické strukturaci. Tyto změny v případě lexikálněsémantických konverzí zasahují buď prominentní povrchověsyntaktickou pozici přímého objektu, viz odd. 4.1, nebo subjektu, viz odd. 4.2, a to takovým způsobem, že lze mluvit o permutaci v přiřazení dvou situačních participantů.

## 4.1 Objektové konverze

#### 4.1.1 Lokativní konverze „Locatum“–„Location“

Centrálním případem lexikálněsémantické konverze je tzv. lokativní alternace (Hovav – Levin, 1988; Pinker, 1989), pro češtinu podrobně popsaná Danešem (1985); okrajově ji zmiňují Grepl a Karlík (1998); její zachycení v rámci FGP podrobně vymezuje Kettnerová (2014). Slovesa umožňující tuto alternaci lze klasifikovat jako slovesa „vytvoření / vytváření souvýskytu“ (odd. 4.1.1a) a „(z)rušení souvýskytu“ (odd. 4.1.1b). Změnami v uspořádání situačních participantů do valenčního rámce jsou v případě daných sloves zasaženy participanty „Locatum“ („Věc měnící své umístění“) a „Location“ („Místo“).4-52

##### 4.1.1a Vytvoření souvýskytu.

Změny v korespondenci situačních participantů „Locatum“ a „Location“ u sloves „vytváření / vytvoření souvýskytu“ zachycuje pravidlo L1, conv_loc_nonpers1, které lze uplatnit u skupiny sloves „vytváření / vytvoření souvýskytu“, u nichž participant „Location“ nevykazuje personické rysy.

Lokativní alternace | Pravidlo L1
Vytvoření souvýskytu | conv_loc_nonpers1
podmínka | conv: Locatum-Location (formation)
| I | II
Locatum | PAT | EFF | MEANS | ∅
Location | DIR2 | DIR3 | LOC | PAT

1. (181) I Řidič načerpal benzín.PAT do nádrže.DIR3. – II Řidič načerpal plnou nádrž.PAT benzínu.

2. (182) I Jana si každý večer natírala krém.PAT na obličej.DIR3. – II Jana si každý večer natírala obličej.PAT krémem.EFF.

3. (183) I Zahradníci dosadili v aleji.LOC mladé stromky.PAT. – II Zahradníci dosadili alej.PAT mladými stromky.EFF.

Ke slovesům „vytváření / vytvoření souvýskytu“, u nichž participant „Location“ vykazuje personické rysy, např. sloveso oblékatimpf — obléci / obléct / obléknoutpf, se vztahuje pravidlo L2, conv_loc_pers1.

Lokativní alternace | Pravidlo L2
Vytvoření souvýskytu | conv_loc_pers1
podmínka | conv: Locatum-Location (formation person)
| I | II
Locatum | PAT | DIR3
Location | ADDR | PAT

1. (184) I Matka oblékla dětem.ADDR sváteční šaty.PAT. – II Matka oblékla děti.PAT do svátečních šatů.DIR3.

##### 4.1.1b Zrušení souvýskytu.

Změny v korespondenci situačních participantů „Locatum“ a „Location“ u sloves „(z)rušení souvýskytu“ popisují dvě pravidla: pravidlo L3, conv_loc_nonpers2, se uplatňuje u skupiny sloves „(z)rušení souvýskytu“, u nichž participant „Location“ nevykazuje personické rysy, např. smazávatimpf — smazatpf1 — smáznoutpf2. Ke slovesům „(z)rušení souvýskytu“, u nichž participant „Location“ personické rysy vykazuje, např. sloveso svlékatimpf — svléknout / svléci / svléctpf, se vztahuje pravidlo L4, conv_loc_pers2.

Lokativní alternace | Pravidlo L3
Zrušení souvýskytu | conv_loc_nonpers2
podmínka | conv: Locatum-Location (destruction)
| I | II
Locatum | PAT | ORIG | ∅
Location | DIR1 | LOC | PAT

1. (185) I Petra vyčistila skvrnu.PAT ze sukně.DIR1. – II Petra vyčistila sukni.PAT od skvrn.ORIG.

2. (186) I Sedláci žali trávu.PAT na palouku.LOC. – II Sedláci žali palouk.PAT.

3. (187) I Učitel smazal nápis.PAT z tabule.DIR1. – II Učitel smazal tabuli.PAT.

Lokativní alternace | Pravidlo L4
Zrušení souvýskytu | conv_loc_pers2
podmínka | conv: Locatum-Location (destruction person)
| I | II
Locatum | PAT | DIR1
Location | ADDR | PAT

1. (188) I Matka svlékala dítěti.ADDR kabát.PAT. – II Matka svlékala dítě.PAT z kabátu.DIR1.

#### 4.1.2 Konverze „Material“–„Product“ („Materiál“–„Produkt“)

Tato alternace je charakteristická pro slovesa, která v jedné syntaktické konstrukci vyjadřují „vytvoření útvaru / celku z „Materiálu““ a ve druhé konstrukci „uspořádání „Materiálu“ do útvaru / celku, který lze chápat jako výsledný „Produkt“ děje“ (189), a dále též pro slovesa, která lze interpretovat jako jejich negativní obdobu a která označují buď „oddělení části z útvaru / celku“, nebo „rozdělení útvaru / celku na části“ (190). Z hlediska pravidlového popisu je však daná sémantická distinkce nerelevantní, viz následující pravidlo L5, conv_mat, které se uplatňuje na obě sémantické skupiny sloves:

Alternace „Material“–„Product“ | Pravidlo L5
| conv_mat
podmínka | conv: Material-Product
| I | II
Material | ORIG | PAT | ADDR & PAT
Product | PAT | EFF

1. (189) I Smíchejte z cukru a žloutků.ORIG hustou pěnu.PAT. – II Smíchejte cukr.PAT se žloutky.ADDR v hustou pěnu.EFF.

2. (190) I Jan lámal kousky.PAT z tabulky čokolády.ORIG. – II Jan lámal tabulku čokolády.PAT na kousky.EFF.

#### 4.1.3 Konverze „Theme“–„Path“ („Pohybující se objekt“–„Prostor“), resp. „Hole“–„Affected_object“ („Otvor“–„Objekt / Prostor“)

Další lexikalizovaná alternace se týká skupiny sloves označujících „pronikání / proniknutí“. U této alternace lze identifikovat dva různě strukturované podtypy, jež je možné parafrázovat jako (i) „způsobit pohyb objektu („Theme“) skrze prostor („Path“)“ a „způsobit proniknutí / pronikání prostoru („Path“) objektem („The-me“)“ (191), nebo jako (ii) „vytvoření otvoru („Hole“) v objektu („Affected_object“)“ a „proděravění objektu / prostoru („Affected_object“)“ (192) (k této alternaci viz Daneš, 1985). Na první skupinu sloves se uplatňuje pravidlo L6, conv_path, zatímco ke druhé skupině se vztahuje pravidlo L7, conv_hole:

Alternace „Theme“–„Path“ | Pravidlo L6
| conv_path
podmínka | conv: Theme-Path
| I | II
Theme | PAT | EFF | MEANS
Path | DIR2 | PAT

1. (191) I Sebevrah si prohnal kulku.PAT hlavou.DIR2. – II Sebevrah si prohnal hlavu.PAT kulkou.EFF.

Alternace „Hole“–„Affected_object“ | Pravidlo L7
| conv_hole
podmínka | conv: Hole-Affected_object
| I | II
Hole | PAT | ∅
Affected_object | DIR3 | DIR2 | LOC | PAT

1. (192) I Rybáři prolomili díru.PAT do ledu.DIR3. – II Rybáři prolomili led.PAT.

#### 4.1.4 Konverze „Affliction“–„Patient“ („Nemoc“–„Pacient“)

Alternace „Affliction“–„Patient“ („Nemoc“–„Pacient“) se objevuje u omezeného počtu sloves fyzického kontaktu, která se vyznačují přítomností situačního participantu s personickými rysy. Situační participanty podléhající změně v přiřazení valenčním doplněním mohou tvořit neodlučitelný celek, avšak syntakticky jsou strukturovány zvlášť.

Přítomnost nevalenčního dativního doplnění slovesa s funktorem BEN v sémanticky méně příznakové konstrukci je podmíněna sémantikou substantiva.4-53 Ačkoli je dativní doplnění vyžadováno sémantikou jména, nikoli slovesa (Razímová, 2004), naplňují dané konstrukce charakteristiku lexikálněsémantické konverze: situační participanty „Affliction“ a „Patient“ podléhají změně v korespondenci s valenčními doplněními a tato změna má povahu permutace participantů zasahující pozici přímého objektu. Změnu v uspořádání situačních participantů do valenčního rámce popisuje následující pravidlo L8, conv_patient:

Alternace „Affliction“–„Patient“ | Pravidlo L8
| conv_patient
podmínka | conv: Affliction-Patient
| I | II
Affliction | PAT | ORIG | ∅
Patient | BEN | PAT

1. (193) I Lékař vyléčil pacientovi.BEN nemoc.PAT. – II Lékař vyléčil pacienta.PAT z nemoci.ORIG.

#### 4.1.5 Konverze „Theme_1“–„Theme_2“ („Předmět 1“–„Předmět 2“)

Daný typ lexikalizované alternace je charakteristický pro slovesa označující změnu přináležitosti (v širším slova smyslu). Tato slovesa charakterizují čtyři situační participanty: „Vlastník 1“, „Vlastník 2“, „Předmět 1“ (přináležející před změnou „Vlastníku 1“) a „Předmět 2“ (přináležející před změnou „Vlastníku 2“). U této lexikálněsémantické konverze přechází „Předmět 1“ z vlastnictví „Vlastníka 1“ do vlastnictví „Vlastníka 2“ směnou za „Předmět 2“: „Vlastník 1“ tak získává „Předmět 2“ a „Vlastník 2“ nabývá „Předmět 1“. Slovesa změny přináležitosti pak umožňují dvojí možnou syntaktickou strukturaci „Předmětu 1“ a „Předmětu 2“: Patientu (PAT), který je realizován v syntakticky významné pozici akuzativního objektu, odpovídá v první konstrukci „Předmět 1“ (a „Předmět 2“ je vyjádřen jako Efekt (EFF) nebo volné doplnění Náhrady (RCMP)), ve druhé konstrukci odpovídá Patientu (PAT) „Předmět 2“ (a „Předmět 1“ je vyjádřen jako Efekt (EFF) (194) nebo nekoresponduje s žádným doplněním, a nemůže být tedy na povrchu vyjádřen (195)).

Alternace „Theme_1“–„Theme_2“ | Pravidlo L9
| conv_theme
podmínka | conv: Theme_1-Theme_2
| I | II
Theme_1 | PAT | EFF | ∅
Theme_2 | EFF | RCMP4-54 | PAT

1. (194) I Vyměnila s kamarádem autíčko.PAT za mašinku.EFF. – II Vyměnila s kamarádem mašinku.PAT za autíčko.EFF.
   (ve smyslu pozbyla autíčko, nabyla mašinku)

2. (195) I Petr splácel majiteli bytu peníze.PAT za nájem.RCMP. – II Petr splácel majiteli bytu nájem.PAT.

## 4.2 Subjektové konverze

#### 4.2.1 Konverze „Bearer_of_action“–„Location“ („Nositel děje“–„Místo“)

Tento typ alternace představuje centrální typ subjektové konverze; komplexní analýzu této alternace pro angličtinu nabízí Dowty (2000); v české jazykovědě její analýzu v rámci konstrukční gramatiky podává Friedová (Fried, 2005), zmiňují ji i Grepl a Karlík (1998), nověji se jí též zabývá Kettnerová (2014). Tato alternace spočívá v rozdílném přiřazení situačních participantů „Nositel děje“ a „Místo“ valenčním doplněním: v jedné syntaktické konstrukci „Nositel děje“ odpovídá Konateli (ACT), zatímco ve druhé je přiřazen Patientu (PAT); „Místo“ jednou koresponduje s volným doplněním místa (LOC), příp. se směrovým doplněním odkud (DIR1), a podruhé s Konatelem (ACT).

Tyto změny vedou k sémantickému posunu mezi syntaktickými konstrukcemi: zatímco slovesa v sémanticky méně příznakové konstrukci označují neakční jednoduchý děj (lze ho charakterizovat jako mimovolní projev „Nositele děje“), v sémanticky příznakové struktuře spojené s holistickým efektem vyjadřují spíše stav „Místa“.4-55 Tyto změny popisuje následující pravidlo L10, conv_bearer:

Alternace „Bearer_of_action“–„Location“ | Pravidlo L10
| conv_bearer
podmínka | conv: Bearer_of_action-Location
| I | II
Bearer_of_action | ACT | PAT
Location | LOC | DIR1 | ACT

1. (196) I V klášteře.LOC zněla majestátní hudba.ACT. – II Klášter.ACT zněl majestátní hudbou.PAT.

2. (197) I Z lesa.DIR1 se ozývala střelba.ACT. – II Les.ACT se ozýval střelbou.PAT.

#### 4.2.2 Konverze „Substance“–„Source“ („Substance“–„Zdroj“)

Alternace „Substance“–„Source“ zasahuje širokou skupinu sloves vyjadřujících neakční jednoduchý děj, kdy je příslušná sémantická situace charakterizována participanty „Substance“ (v širokém smyslu) a její „Zdroj“. Tyto participanty podléhají změnám v přiřazení valenčním doplněním, které mají charakter permutace zasahující povrchověsyntaktickou pozici subjektu: v sémanticky méně příznakové konstrukci je v subjektu vyjádřena „Substance“, zatímco v syntaktické konstrukci spojené s holistickou interpretací participant „Zdroj“. Jde o skupinu sloves co do valenční charakteristiky značně heterogenní. Na tato slovesa se uplatňuje následující pravidlo L11, conv_substance:

Alternace „Substance“–„Source“ | Pravidlo L11
| conv_substance
podmínka | conv: Substance-Source
| I | II
Substance | ACT | PAT | ∅
Source | DIR1 | LOC | ACT

1. (198) I Barva.ACT pustila z trička.DIR1. – II Tričko.ACT pustilo barvu.PAT.

2. (199) I Na letišti.LOC explodovala bomba.ACT. – II Letiště.ACT explodovalo.

#### 4.2.3 Lokativní konverze bez objektu „Locatum“–„Location“ (objectless)

Konverzní změny zasahující subjekt vykazuje též širší skupina sloves svou sémantikou blízkých slovesům podléhajícím objektové lokativní konverzi, a to slovesům vyjadřujícím „(z)rušení souvýskytu“. Pro tato slovesa formulujeme následující pravidlo L12, conv_loc_objectless:

Alternace „Locatum“–„Location“ (objectless) | Pravidlo L12
| conv_loc_objectless
podmínka | conv: Locatum-Location (objectless)
| I | II
Locatum | ACT | PAT | ∅
Location | DIR1 | ACT

1. (200) I Z plného popelníku.DIR1 se vysypal popel.ACT. – II Popelník.ACT se vysypal.

2. (201) I Bláto.ACT se deštěm očistilo z chodníků.DIR1. – II Chodníky.ACT se deštěm očistily od bláta.PAT.

# 5 Rozdílná strukturní realizace situačního participantu

## 5.1 Rozdílná strukturní realizace participantu u sloves pohybu

Velká skupina sloves pohybu (odd. 5.1.1 až 5.1.3) a tři další skupiny sloves (odd. 5.1.4 až 5.1.6) se vyznačují tím, že umožňují participant odpovídající „Východisku“, „Dráze“ pohybu nebo jeho „Cíli“ a sémanticky obdobné participanty hloubkověsyntakticky strukturovat odlišným způsobem: (i) buď jako volné doplnění označující směr odkud DIR1 („Východisko“), kudy DIR2 („Dráha“, „Mez“, „Prostor“) nebo kam DIR3 („Cíl“, „Zasažený cíl“), případně jako lokaci LOC („Prostor“), nebo (ii) jako PAT. Syntaktická konstrukce s PAT je spojena s holistickou interpretací odpovídajícího participantu (více viz Benešová, 2004; Kettnerová, 2014).

#### 5.1.1 Participant „Source“ („Východisko“)

Rozdílná realizace participantu „Source“ | Pravidlo L13
| multiple_source
podmínka | multiple: Source
| I | II
Source | DIR1 | PAT

1. (202) I Výletníci scházeli z kopce.DIR1. – II Výletníci scházeli kopec.PAT.

#### 5.1.2 Participant „Path“ („Dráha“)

Rozdílná realizace participantu „Path“ | Pravidlo L14
| multiple_path
podmínka | multiple: Path
| I | II
Path | DIR2 | PAT

1. (203) I Děti probíhaly lesem.DIR2. – II Děti probíhaly les.PAT.

#### 5.1.3 Participant „Goal“ („Cíl“)

Rozdílná realizace participantu „Goal“ | Pravidlo L15
| multiple_goal
podmínka | multiple: Goal
| I | II
Goal | DIR3 | PAT

1. (204) I Výprava vyšla na kopec.DIR3. – II Výprava vyšla kopec.PAT.

#### 5.1.4 Participant „Boundary“ („Mez“)

Rozdílná realizace participantu „Boundary“ | Pravidlo L16
| multiple_boundary
podmínka | multiple: Boundary
| I | II
Boundary | DIR2 | PAT

1. (205) I Ostružiní přerůstá přes plot.DIR2. – II Ostružiní přerůstá plot.PAT.

#### 5.1.5 Participant „Area“ („Prostor“)

Rozdílná realizace participantu „Area“ | Pravidlo L17
| multiple_area
podmínka | multiple: Area
| I | II
Area | DIR2 | LOC | PAT

1. (206) I Kostelem.DIR2 prolínala vůně kadidla. – II Kostel.PAT prolínala vůně kadidla.

#### 5.1.6 Participant „Impactee“ („Zasažený cíl“)

Rozdílná realizace participantu „Impactee“ | Pravidlo L18
| multiple_impactee
podmínka | multiple: Impactee
| I | II
Impactee | DIR3 | PAT

1. (207) I Jan bušil do soupeře.DIR3 pěstmi. – II Jan bušil soupeře.PAT pěstmi.

## 5.2 Rozdílná strukturní realizace participantu u sloves umístění

#### 5.2.1 Participant „Location“ („Místo“)

Dalším typem časté lexikalizované alternace s rozdílným strukturním vyjádřením téhož situačního participantu je alternace týkající se dynamického a statického vyjádření lokace (Hirschová, 1977). V případě dynamického vyjádření participant „Místo“ koresponduje s valenčním volným doplněním směru DIR1 (směr odkud) (208) nebo DIR3 (směr kam) (209), u statického vyjádření je realizován jako valenční volné doplnění místa LOC (kde).

U sloves s akuzativním doplněním PAT je změnou lokalizace, jejímž původcem je Konatel (ACT), zasaženo toto doplnění (208) a (209); oproti tomu u sloves bez akuzativního doplnění podléhá změně lokace Konatel (ACT), který je zároveň i původcem dané změny (210).

Rozdílná realizace participantu „Location“ | Pravidlo L19
| multiple_location
podmínka | multiple: Location
| I | II
Location | DIR1 | DIR3 | LOC

1. (208) I Úřad systematicky vymazával z matriky.DIR1 některé údaje. – II Úřad systematicky vymazával v matrice.LOC některé údaje.

2. (209) I Nájemníci ukládají odpad do kontejneru.DIR3. – II Nájemníci ukládají odpad v kontejneru.LOC.

3. (210) I Do Prahy.DIR3 se sjížděli delegáti z celých Čech. – II V Praze.LOC se sjeli delegáti z celých Čech.

Poznámka:
Některá slovesa umožňují vyjadřovat různý směr pohybu či transportu určitého objektu, příp. různou orientaci objektu: tato sémantická změna je reflektována odlišným obligatorním volným doplněním, např. Vynášeli haraburdí z domu.DIR1. vs. Vynášeli haraburdí na půdu.DIR3., Myš se z klece.DIR1 nedostane. vs. Myš se do domu.DIR3 nedostane. nebo Dráty trčely z betonu.DIR1 vs. Dráty trčely do výšky.DIR3 (více viz Lopatková – Panevová, 2007). I když se jedná o sémanticky velmi blízká užití sloves, nespojujeme je alternací, jelikož se směrovým doplněním korespondují odlišné situační participanty: volnému doplnění typu DIR1, označujícímu směr odkud, odpovídá participant „Source“, zatímco doplnění typu DIR3, vyjadřující směr kam, koresponduje s participantem „Goal“.

## 5.3 Rozdílná strukturní realizace participantu u sloves cogitandi a u sloves pocitů a stavů

U některých sloves cogitandi a sloves vyjadřujících pocity a stavy může být participant „Judgment“, „Subject_matter“ nebo „State“ („Posouzení“, „Tematika / Zaměření“ nebo „Stav“), odpovídající určité abstraktní entitě, realizován buď jako aktant, a to jako PAT nebo jako EFF (v takovém případě je morfematické vyjádření dáno rekcí slovesa), nebo jako volné doplnění adverbiálního typu MANN (v takovém případě jeho forma vyplývá z typu funktoru).

#### 5.3.1 Participant „Judgment“ („Posouzení“)

Rozdílná realizace participantu „Judgment“ | Pravidlo L20
| multiple_judg
podmínka | multiple: Judgment
| I | II
Judgment | EFF | MANN

1. (211) I Tuto událost vykládáme jako nepolitickou.EFF. – II Tuto událost vykládáme nepoliticky.MANN.

#### 5.3.2 Participant „Subject_matter“ („Tematika / Zaměření“)

Pro slovesa s akuzativním PAT, kde je participant „Subject_matter“ přiřazen buď doplnění EFF, nebo doplnění MANN, formulujeme pravidlo L21, multiple_subject:

Rozdílná realizace participantu „Subject_matter“ | Pravidlo L21
| multiple_subject
podmínka | multiple: Subject_matter
| I | II
Subject_matter | EFF | MANN

1. (212) I Studenti zaměřovali své studium spíš na lingvistiku.EFF. – II Studenti zaměřovali své studium spíš lingvisticky.MANN.

Změny v přiřazení participantu „Subject_matter“ valenčním doplněním u sloves bez akuzativního doplnění popisuje pravidlo L22, multiple_subject (objectless).

Rozdílná realizace participantu „Subject_matter“ | Pravidlo L22
| multiple_subject (objectless)
podmínka | multiple: Subject_matter (objectless)
| I | II
Subject_matter | PAT | MANN

1. (213) I Student se zaměřoval spíš na lingvistiku.PAT. – II Student se zaměřoval spíš lingvisticky.MANN.

#### 5.3.3 Participant „State“ („Stav“)

Změny v korespondenci participantu „State“ („Stav“) a valenčních doplnění u sloves s akuzativním PAT, kde je participant „State“ přiřazen buď doplnění EFF, nebo doplnění MANN, odráží pravidlo L23, multiple_state.

Rozdílná realizace participantu „State“ | Pravidlo L23
| multiple_state
podmínka | multiple: State
| I | II
State | EFF | MANN

1. (214) I Zprávy o něm ho uchovaly živého.EFF. – II Zprávy o něm ho uchovaly naživu.MANN.

Tytéž změny u sloves bez akuzativního PAT popisuje pravidlo L24, multiple_state (objectless).

Rozdílná realizace participantu „State“ | Pravidlo L24
| multiple_state (objectless)
podmínka | multiple: State (objectless)
| I | II
State | PAT | MANN

1. (215) I Jan se v poslední době cítí jako stařík.PAT. – II Jan se v poslední době cítí staře.MANN.

# 6 Rozpad situačního participantu

Strukturní rozpad situačního participantu označuje takové změny ve valenčním rámci slovesa, kdy jedinému situačnímu participantu odpovídá v jedné syntaktické konstrukci jediné valenční doplnění, v druhé konstrukci pak daný participant koresponduje se dvěma doplněními. V češtině tento typ nekonverzní alternace umožňují slovesa, která k sobě jako jedno z doplnění vážou participant propoziční povahy – jde o slovesa dicendi (odd. 6.1), o slovesa cogitandi (odd. 6.2 a 6.3) a o slovesa percipiendi (odd. 6.4) – a dále některá slovesa pohybu (odd. 6.5). U sloves dicendi a cogitandi je tento jev v české jazykovědě obvykle označován jako rozpad tématu, příp. syžetu, a dikta (k této problematice viz Kettnerová, 2009; Daneš – Hlavsa, 1987; Konečná, 1966).6-56 V případě sloves percipiendi je rozpad situačního participantu spojován s parafrázemi konstrukcí s tzv. slovanským akuzativem s infinitivem (Panevová, 2008). Slovesa percipiendi a slovesa cogitandi, uvedená v odd. 6.3, vykazují některé společné syntaktické rysy, a bývají proto studovány v rámci společné kategorie tzv. raisingu, viz (Carnie, 2007).

Rozpad situačního participantu u každé skupiny sloves popisuje právě jedno pravidlo. Ve sloupci I vždy uvádíme to valenční doplnění, jemuž situační participant odpovídá v syntaktické konstrukci bez strukturního rozpadu, a ve sloupci II dvě doplnění, s nimiž daný participant koresponduje v konstrukci se strukturním rozpadem.

#### 6.1 Rozpad participantu „Information“ („Informace“)

Rozpad participantu „Information“ | Pravidlo L25
| split_inform
podmínka | split: Information
| I | II
Information | PAT | PAT & EFF

1. (216) I Sousedka si stěžovala rodičům, (že syn pije).PAT. – II Sousedka si stěžovala rodičům na syna.PAT, (že pije).EFF.

2. (217) I Lékaři mu tvrdili, (že je ta nemoc nevyléčitelná).PAT. – II Lékaři mu o té nemoci.PAT tvrdili, (že je nevyléčitelná).EFF.

#### 6.2 Rozpad participantu „Phenomenon“ („Myšlenka“)

Rozpad participantu „Phenomenon“ | Pravidlo L26
| split_phenomenon
podmínka | split: Phenomenon
| I | II
Phenomenon | PAT | PAT & EFF

1. (218) I Jan si pomyslel, (že je Petra nafoukaná).PAT. – II Jan si pomyslel o Petře.PAT, (že je nafoukaná).EFF.

#### 6.3 Rozpad participantu „Inference“ („Úsudek“)

Rozpad participantu „Inference“ | Pravidlo L27
| split_inference
podmínka | split: Inference
| I | II
Inference | PAT | PAT & EFF

1. (219) I Zdálo se mi, (že je Petr v pořádku).PAT. – II Petr.PAT se mi zdál (být v pořádku).EFF.

#### 6.4 Rozpad participantu „Stimul“ („Podnět“)

Rozpad participantu „Stimul“ | Pravidlo L28
| split_stimul
podmínka | split: Stimul
| I | II
Stimul | PAT | PAT & EFF

1. (220) I V okně prvního poschodí zahlédla, (jak se na ni její manžel dívá).PAT. – II V okně prvního poschodí zahlédla svého manžela.PAT, (jak se na ni dívá).EFF.

#### 6.5 Rozpad participantu „Path“ („Dráha“)

Rozpad participantu „Path“ | Pravidlo L29
| split_path
podmínka | split: Path
| I | II
Path | DIR2 | DIR1 & DIR3

1. (221) I Přívoz převáží turisty přes řeku.DIR2. – II Přívoz převáží turisty z jedné strany.DIR1 řeky na druhou.DIR3.

### Poznámky

- ^[1-1] Korpusová data dokládají možnost kombinovat diateze s reciprocitou, srov. Sňatek dětí byl předem dohodnut oběma rodinami; kombinace různých typů gramatikalizovaných alternací však dosud není pro češtinu dostatečně prozkoumána, stávající pravidla proto možnost kombinací různých gramatikalizovaných alternací nepostihují.
- ^[1-2] Pravidla pro diateze prototypicky nemění počet a obligatornost valenčních doplnění, výjimkou je dispoziční diateze, zde odd. 1.3, u níž v odvozeném rámci přibývá obligatorní doplnění způsobu (MANN), a některé typy posesivního rezultativu, zde odd. 1.4.
- ^[1-3] U trpného participia rozlišujeme 1. a 4. pád; tvarem se však liší pouze v singuláru ženského rodu (-na/-ta vs. -nu/-tu) a v plurálu mužského životného rodu (-ni/-ti vs. -ny/-ty) (Urešová, 2011, s. 142), výjimečně též v singuláru mužského životného rodu (-n/-t vs. -na/-ta), např.:
  Nemocnici nebyla prodloužena smlouva se zdravotní pojišťovnou.
  Nemocnice nedostala prodlouženu smlouvu se zdravotní pojišťovnou.
- ^[1-4] Pravidlo pro pasivní a rezultativní prostou diatezi explicitně vyznačuje pomocné sloveso být, které však zastupuje i iterativa bývat a bývávat.
- ^[1-5] Vzhledem k homonymii mezi participiem trpným a krátkým tvarem deverbativního adjektiva rozlišujeme:
  (i) konstrukce s pomocným slovesem být a -n/t-ovým participiem; tyto konstrukce interpretujeme jako příznakový člen diateze pasivní, např. V šest hodin bylo Petrem otevřeno okno., či diateze rezultativní, např. V sedm hodin bylo okno již dávno otevřeno. a
  (ii) konstrukce se sponou být a -n/t-ovým tvarem adjektiva tvořící verbonominální struktury, např. Okno je otevřeno (=otevřené) dokořán.; verbonominální struktury nejsou ve slovníku zachyceny.
- ^[1-6] Toto pravidlo se netýká (aktuální) elipsy subjektu v příznakových konstrukcích:
  krmitimpf ACT1 PAT4 MEANStyp7
  X=PAT4 → 1 Je dobré slyšet pravdu, ne lži, kterými jsme opakovaně krmeni.
  (příslušné doplňkové pravidlo G2, pass_trans_acc, viz níže, určuje X jako doplnění akuzativní, zde PAT; v příkladové větě toto doplnění sice není povrchověsyntakticky vyjádřeno, jde ale o případ aktuální elipsy, shoda je proto dána tímto nevyjádřeným doplněním)
- ^[1-7] U sloves, která mají dvě akuzativní doplnění, je možné pravidlo aplikovat na jedno nebo na druhé z nich, nikoli však na obě současně:
  vyučovatimpf — vyučitpf ACT1 ADDR4 PAT3, 4, v+6, inf, aby, ať
  X=PAT … učitelství pro střední školu bude vyučováno na přírodovědecké a filozofické fakultě.
  X=ADDR … každý vychovatel vedle své pedagogické odbornosti je vyučen nějakému řemeslu.
  Pravidlo nezachycuje skutečnost, že volba doplnění, které se stane subjektem, může blokovat vyjádření druhého akuzativního doplnění, např. Pavel je učen Petrem matematiku, ale *Matematika je učena Petrem Pavla (viz Karlík et al., 2002, s. 417).
- ^[1-8] Pro účely popisu diatezí zařazujeme k tradičním tranzitivním slovesům též ta slovesa s genitivním doplněním, která vykazují obdobné syntaktické chování, viz odd. 1.1.2.1b a 1.1.2.1c.
- ^[1-9] Korpusová data ukazují, že u odvozených reflexiv lze konstrukce skládající se z -n/t-ového tvaru a slovesa být interpretovat spíše jako verbonominální predikát:
  ponořovat seimpf — ponořit sepf ACT1 DIR3
  V okamžiku maximální fáze […] bude měsíční disk do stínu ponořen přibližně z 81 procent.
  V některých případech jsou tyto verbonominální konstrukce homonymní s rezultativní konstrukcí příslušného nereflexivního slovesa:
  angažovatbiasp ACT1 PAT4 LOCtyp
  angažovat sebiasp ACT1 LOCtyp REGtypv+6
  Palestinci musejí dále ukončit násilí a zahájit postup vůči všem, kteří jsou angažováni v teroristických aktivitách.
  Otázka, proč se sekundární reflexiva v tomto aspektu chovají odlišně od reflexiv tantum a nereflexivních sloves, zasluhuje další zkoumání.
- ^[1-10] Tento příkaz zamezuje zdvojení reflexiva se/si, pokud se pravidlo G6, deagent_basic, aplikuje na reflexivní slovesa, např. slovesa modlit seimpf (32) a poslechnout siimpf (33).
- ^[1-11] Toto pravidlo se netýká (aktuální) elipsy, kde je shoda mezi doplněním X a slovesem zachována:
  zdobitimpf ACT1 PAT4 MEANStyp7
  X=PAT4 → 1 Stromky se zavěšovaly u stropu nebo stály na stolku. Zpočátku se zdobily jen skromně.
  (příslušné doplňkové pravidlo G7, deagent_trans_acc, viz níže, určuje X jako doplnění akuzativní, zde PAT; v příkladové větě toto doplnění sice není povrchověsyntakticky vyjádřeno, jde ale o aktuální elipsu, shoda je proto dána tímto nevyjádřeným doplněním)
- ^[1-12] U sloves, která mají dvě akuzativní doplnění, je možné pravidlo aplikovat na jedno nebo na druhé z nich, nikoli však na obě současně:
  vyučovatimpf — vyučitpf ACT1 ADDR4 PAT3, 4, v+6, inf, aby, ať
  X=PAT4 → 1 Ve speciálních třídách se nevyučují cizí jazyky.
  X=ADDR4 → 1 … nemocnice, kde se vyučovali medici.
- ^[1-13] Pro účely popisu diatezí zařazujeme ta slovesa s genitivním doplněním, u kterých může v příznakové konstrukci deagentní diateze původní genitivní doplnění nabývat tvar nominativu, ke slovesům tranzitivním, viz odd. 1.2.2.1b.
- ^[1-14] Výjimečně (zejména ve významu "dobře / snadno / příjemně") nemusí být MANN v povrchověsyntaktické struktuře vyjádřen; k tomu dochází zejména u sloves mluvení, např. Vám se to radí / mluví / řekne / povídá / kecá., lze to však doložit i u jiných sloves, např. Vám se to chodí., Vám se to žije. Tyto struktury se vyznačují přítomností zdůrazňovací částice to:
  mluvitimpf ACT1 ADDRoptk+3, na+4 PATopto+6 MANNtyp
  Vám se to mluví, ale nejdřív za mě někdo musí zaplatit.
- ^[1-15] Slovesa ovšem mohou tvořit i posesivní rezultativní konstrukce typu, který není v hesle exemplifikován.
- ^[1-16] U trpného participia rozlišujeme 1. a 4. pád; tvarem se však liší pouze v singuláru ženského rodu (-na/-ta vs. -nu/-tu) a v plurálu mužského životného rodu (-ni/-ti vs. -ny/-ty) (Urešová, 2011, s. 142), výjimečně též v singuláru mužského životného rodu (-n/-t vs. -na/-ta), viz též poznámku pod čarou 1-3.
- ^[1-17] Pravidlo pro posesivní rezultativ explicitně vyznačuje pomocné sloveso mít, uváděné změny se ovšem vztahují i na rezultativní konstrukce s pomocným iterativním slovesem mívat.
- ^[1-18] Pravidla pro posesivní rezultativ explicitně vyznačují pomocné sloveso mít, uváděné změny se však opět vztahují i na rezultativní konstrukce s pomocným iterativním slovesem mívat.
- ^[1-19] Předpokládáme, že BEN přidaný pravidlem G14, res_conv_basic2, by v nepříznakovém členu diateze byl realizován dativem; jelikož ovšem pravidlo specifikuje pouze formu charakteristickou pro příznakový člen diateze, objevuje se zde až jeho transformovaná forma, tedy nominativ.
- ^[1-20] Tyto konstrukce jsou (podobně jako konstrukce (86)–(88) uvedené na závěr odd. 1.4.2.2) již na přechodu k verbonominálním predikátům se sponou mít (viz Šmilauer, 1966); ve VALLEXu jsou zachyceny v rámci konstrukcí posesivního rezultativu.
- ^[1-21] V tomto počtu nejsou zahrnuty lexikální jednotky sloves s fakultativním reflexivem si.
- ^[1-22] Tyto konstrukce jsou (podobně jako konstrukce (71)–(75) uvedené výše v odd. 1.4.2.1) již na přechodu k verbonominálním predikátům se sponou mít (viz Šmilauer, 1966); ve VALLEXu jsou zachyceny v rámci konstrukcí posesivního rezultativu.
- ^[1-23] U trpného participia rozlišujeme 1. a 4. pád; tvarem se však liší pouze v singuláru ženského rodu (-na/-ta vs. -nu/-tu) a v plurálu mužského životného rodu (-ni/-ti vs. -ny/-ty) (Urešová, 2011, s. 142), výjimečně též v singuláru mužského životného rodu (-n/-t vs. -na/-ta), viz též poznámku pod čarou 1-3.
- ^[1-24] Do recipientní pasivní diateze mohou ovšem vstupovat i některá slovesa, která valenční doplnění vyjádřené dativem typu ADDR nebo PAT nemají a u nichž ve VALLEXu není v rámci vyznačen ani BEN jako typické doplnění. Příznaková konstrukce recipientní pasivní diateze ovšem vyžaduje určité doplnění vyjádřené v povrchověsyntaktické pozici subjektu; pro takové případy by bylo nutné pravidlo recipient modifikovat: navíc ke změnám popsaným v pravidle G17, recipient, by dané pravidlo muselo umožňovat do příznakových konstrukcí vkládat BEN1 (obdobně jako pravidlo G14, poss_conv_basic2, viz odd. 1.4.2.1 výše), např.:
  uvolňovatimpf — uvolnitpf ACT1 PAT4 AIMtypna+4, pro+4
  BEN → 1 Každý občan však dostal uvolněno 500 korun nového oběživa.
  Informace o recipientní pasivní diatezi však není v případech, kdy sloveso nemá dativní doplnění, ve VALLEXu vyznačena, proto zde pravidlo neformulujeme.
- ^[2-25] Připomeňme zde, že VALLEX se omezuje na zachycení těch případů syntaktické reflexivity, která může být vyjádřena krátkými (klitickými) tvary reflexivního osobního zájmena. Nepokrývá tedy méně problematické případy, kdy je gramatikalizována dlouhá forma reflexiva, např. v předložkové skupině či v pádech, kde reflexivum nemá klitickou formu (tedy v genitivu nebo v instrumentálu), viz odd. GUIDE > 4.3.
- ^[2-26] Možnost kombinovat syntaktickou reflexivitu a diateze, příp. reciprocitu, není pro češtinu dosud dostatečně prozkoumána, při pravidlovém popisu proto od možných kombinací zcela odhlížíme, viz též poznámku pod čarou 4-35.
- ^[2-27] Slovník VALLEX se při zachycení reflexivity dativního doplnění omezuje na případy, kdy reflexivní osobní zájmeno může být vyjádřeno krátkou (klitickou) formou, viz zde poznámku pod čarou 2-25 (více též odd. GUIDE > 4.3). Protože v těchto případech může být příslušné valenční doplnění vyjádřeno kromě dativu též jinými morfematickými formami, ošetřuje pravidlo i chování těchto forem – výsledný valenční rámec pro reflexivní konstrukce tak uvádí všechny formy přípustné pro reflexivní konstrukci (tedy nejen reflexivní zájmeno v dativu).
- ^[2-28] Plně formalizované pravidlo pro předložkové skupiny se rozpadá na varianty podle typu předložkové skupiny, zde pro přehlednost a lepší orientaci volíme tento neformální zápis.
- ^[2-29] Slovník VALLEX se při zachycení reflexivity akuzativního doplnění omezuje na případy, kdy reflexivní osobní zájmeno může být vyjádřeno krátkou (klitickou) formou, viz zde poznámku pod čarou 2-25 (více též odd. GUIDE > 4.3). Protože i v těchto případech může být příslušné valenční doplnění vyjádřeno kromě akuzativu též jinými morfematickými formami, ošetřuje pravidlo i chování těchto forem – výsledný valenční rámec pro reflexivní konstrukce tak uvádí všechny formy přípustné pro reflexivní konstrukci (tedy nejen reflexivní zájmeno v akuzativu).
- ^[2-30] Plně formalizované pravidlo pro předložkové skupiny se rozpadá na varianty podle typu předložkové skupiny, zde pro přehlednost a lepší orientaci necháváme tento neformální zápis.
- ^[2-31] Plně formalizované pravidlo pro předložkové skupiny se rozpadá na varianty podle typu předložkové skupiny, zde pro přehlednost a lepší orientaci volíme tento neformální zápis.
- ^[2-32] Pravidlo G20 umožňuje oba typy shody doplňku, přestože korpusová data dokládají pouze řídký výskyt shody s akuzativním klitickým reflexivem.
- ^[3-33] V češtině je dále možné reciprocitu vyjádřit též lexikálně, a to výrazy jeden – druhý, obsazujícími valenční doplnění, která jsou ve vztahu symetrie, srov. Chtěli jsme sice jeden.ACT(1) druhému.ADDR(3) pomoct, ale nikdy neotvírat třináctou komnatu., Nejsou schopni odlišit jednoho sourozence.PAT(4) od druhého.ORIG(od+2). V těchto případech nedochází ke změnám v korespondenci participantů a členů valenčního rámce, valenční rámec zůstává formálně zachován, reciproční význam je tu vyjádřen pouze lexikálně, a proto tyto případy v pravidlech nezachycujeme.
- ^[3-34] Jak ukazuje např. věta Sňatek dětí byl předem dohodnut oběma rodinami., čeština umožňuje kombinovat reciprocitu a diateze. Pro odvození valenčního rámce popisujícího užití slovesa v dané struktuře by bylo třeba napřed odvodit rámec pro reciproční konstrukci a teprve poté na něj aplikovat pravidla pro odvození rámce pro příznakovou konstrukci pasivní diateze. Kombinovatelnost reciprocity s diatezemi však není pro češtinu dostatečně prozkoumána, při jejím pravidlovém popisu proto od této problematiky odhlížíme s vědomím toho, že zasluhuje další výzkum.
- ^[3-35] Ve VALLEXu je Adresát (ADDR) vstupující do reciprocity s Konatelem (ACT) nejčastěji vyjádřen dativem, předložkovou skupinou s+7 nebo akuzativem, dále může být realizován též předložkovými skupinami na+4, na+6, proti+3; méně často (pod 10 výskytů) je ve VALLEXu vyjádřen formami k+3, mezi+4 nebo genitivem, zcela okrajově pak formami před+4 a před+7. Některé z těchto lexikálních jednotek umožňují vyjádřit ADDR alternativně též dalšími formami, jejichž přítomnost v recipročních konstrukcích však korpusová data nedokládají; pro tyto formy tedy příslušná pravidla neformulujeme.
- ^[3-36] Viz poznámku o hodnocení výrazu mezi sebou v odd. 4.1.2.1a.
- ^[3-37] Možnost tvořit daný typ reciprocity je ve VALLEXu doložena pouze u následujících sloves: napsat (si)pf, psát (si)impf, říkat (si)impf — říci / říct (si)pf. Výskyt těchto sloves v recipročních konstrukcích sice korpusový materiál nedokládá, avšak předpokládáme, že je možný.
- ^[3-38] U sloves s fakultativním reflexivem si tvořících daný typ reciproční konstrukce (viz poznámku pod čarou 3-37) tvoří reflexivní konstrukce pouze ty lexikální jednotky, které jsou reprezentovány nereflexivní podobou lemmatu.
- ^[3-39] Viz poznámku o hodnocení výrazu mezi sebou v odd. 4.1.2.1a.
- ^[3-40] Viz poznámku o hodnocení výrazu mezi sebou v odd. 4.1.2.1a.
- ^[3-41] V případě reflexivních sloves s dativním ADDR lze nulovou formu daného doplnění interpretovat jako důsledek haplologie, tedy splynutí klitické formy reflexivního zájmena v dativu a reflexiva představujícího součást lemmatu slovesa, viz odd. 3.1.2.1b. V případě reflexivních sloves s genitivním ADDR by toto vysvětlení bylo možné, pouze pokud bychom v těchto kontextech připustili interpretaci klitického tvaru reflexiva se jako genitivního tvaru reflexivního osobního zájmena, k dané problematice viz též Oliva (2001).
- ^[3-42] Reflexivita genitivního doplnění není ve VALLEXu vyznačena, viz poznámku pod čarou 2-25 v kapitole 2.
- ^[3-43] Zdůrazněme, že ve VALLEXu je reciprocita uváděna u inherentních reciprok, odvozených reciprok i sloves, která sice inherentní rys reciprocity nenesou, ale reciproční užití umožňují. V případě odvozených reciprok se reciprocita uvádí jak u slovesa, od nějž je reciproční sloveso odvozeno, tak u odvozeného reciproka (atribut recipr), např.:
  vyjasňovatimpf — vyjasnitpf ACT1 ADDR3 PAT4, zda, že, cont
  recipr: ACT-ADDR Vzájemně si vyjasňovali svá stanoviska.
  vyjasňovat siimpf — vyjasnit sipf ACT1 ADDRs+7 PAT4, zda, že, cont
  recipr: ACT-ADDR Právě si to (spolu) vyjasňují.
- ^[3-44] Viz poznámku o hodnocení výrazu mezi sebou v odd. 4.1.2.1a.
- ^[3-45] Příklady dokládají, že u slovesa s ADDR vyjádřeným předložkovou skupinou mezi+4 se při recipročním užití mohou kumulovat formy reflexivního osobního zájmena, a to klitická dativní forma a předložková forma mezi+4: Úkoly si mezi sebe dělí EU, členské státy a jejich regiony a obce. V těchto případech hodnotíme formu mezi+4 jako ADDR a dativ jako BEN. VALLEX popisuje čtyři takové lexikální jednotky (dělitimpf, rozdávatimpf — rozdatpf, rozdělovatimpf1 — rozdíletimpf2 — rozdělitpf a rozkládatimpf — rozložitpf).
- ^[3-46] U sloves dělitimpf, rozdělovatimpf1 — rozdíletimpf2 — rozdělitpf a rozdávatimpf — rozdatpf, u nichž má ADDR ve valenčním rámci popisujícím nereciproční užití formu dativu a předložkové skupiny mezi+4, se často vyskytují reciproční konstrukce obsahující předložkovou skupinu mezi sebou, aniž by ADDR byl vyjádřen reflexivním zájmenem ve tvaru daném valenčním rámcem, např. Je to velká akce, takže jsme se od září pravidelně scházeli a rozdělovali mezi sebou úkoly, kdo a co zařídí… Jelikož je v nerecipročních strukturách výše uvedených sloves forma mezi+7 pro vyjádření ADDR negramatická, viz *Otec rozděloval úkoly mezi Janem a Petrem., předpokládáme, že ve strukturách recipročních jde o kontaminaci vazeb mezi+4, představující formu ADDR předepsanou nepříznakovým valenčním rámcem, a mezi+7, sloužící ke zdůraznění recipročního významu, viz odd. 3.1.2.1a.
- ^[3-47] Reflexivita doplnění vyjádřených předložkovou skupinou není ve VALLEXu vyznačena, viz poznámku pod čarou 2-25 v kapitole 2.
- ^[3-48] Ke kombinaci reciprocity s diatezí (např. … v rámci jednoho symbolu mohou být navzájem zaměněny signály vedoucí na vývody se stejnou nenulovou hodnotou.) viz poznámku pod čarou 3-34 v odd. 3.1.
- ^[3-49] Ve VALLEXu se reciprocita PAT-EFF vyskytla u více než třiceti lexikálních jednotek; EFF vstupující do reciproční konstrukce je v nich nejčastěji vyjádřen předložkovými skupinami s+7, k+3 nebo za+4; okrajově se dále vyskytly formy na+4 a proti+3. Některé z těchto lexikálních jednotek umožňují vyjádřit EFF alternativně též dalšími formami, u kterých však v korpusových datech není doložen výskyt v recipročních konstrukcích; pro tyto formy proto příslušná pravidla neformulujeme.
- ^[3-50] Předložkovou skupinu za sebe sice korpusový materiál v recipročních konstrukcích nedokládá, ale předpokládáme, že její přítomnost je možná.
- ^[3-51] V některých případech však tento participant náleží nikoli slovesu, ale jménu, a lze ho tak strukturovat jako valenční doplnění jména, např. Řidič načerpal plnou nádrž benzínu. (viz příklad (181) a pravidlo L1, conv_loc_nonpers1).
- ^[4-52] Napříč oběma skupinami sloves souvýskytu probíhá významová distinkce podle toho, zda lze situační participanty, tedy „Locatum“ a „Location“, specifikovat buď jako „Container“ („Kontejner“) a „Content“ („Obsah“) („vztah uvnitř“), nebo jako „Surface“ („Povrch“) a „Coverage“ („Pokrytí“) („vztah na povrchu“). Do pravidel se však tato významová distinkce nepromítá (více viz Kettnerová, 2014).
- ^[4-53] K substantivům obligatorně vyžadujícím doplnění přináležitosti viz Piťhu (1992).
- ^[4-54] Jedinou výjimku z uvedeného pravidla představuje sloveso doplácetimpf — doplatitpf; dané sloveso má ve svém valenčním rámci popisujícím syntaktickou konstrukci I jak aktant EFF, tak volné doplnění RCMP, participant „Theme_2“ však koresponduje pouze s volným doplněním RCMP, např. Podnik Petrovi k platu.EFF doplatil nemalé odměny.PAT za jeho mimořádné výkony.RCMP.
- ^[4-55] Konstrukce s formálním subjektem to typu V domě to vonělo vanilkou ve slovníku v současnosti zachyceny nejsou. Jejich možný pravidlový popis uvádí Kettnerová (2014).
- ^[6-56] V české jazykovědě je participantu propoziční povahy u sloves dicendi i cogitandi přisuzována stejná kognitivní role (Daneš – Hlavsa, 1987). V databázi FrameNet, kterou se při označování kognitivních rolí situačních participantů inspirujeme, jsou pro dané skupiny sloves rozlišovány odlišné participanty, a to „Information“ (pro slovesa dicendi) a „Phenomenon“, příp. „Inference“ (pro slovesa cogitandi). Zde se držíme posledně uvedeného rozlišení s vědomím toho, že daná problematika nebyla dosud v češtině (zejména u sloves cogitandi) dostatečně prozkoumána.

### Seznam literatury

- Benešová (2004)
  Benešová, V. (2004): Delimitace lexií českých sloves z hlediska jejich syntaktických vlastností. Diplomová práce. Praha, Univerzita Karlova v Praze, Filozofická fakulta.
- Carnie (2007)
  Carnie, A. (2007): Syntax: A Generative Introduction.: Malden – Oxford – Carlton, Blackwell Publishing.
- Daneš (1985)
  Daneš, F. (1985): Věta a text.: Praha, Academia.
- Daneš – Hlavsa (1987)
  Daneš, F. – Hlavsa, Z. (1987): Větné vzorce v češtině. Praha, Academia. (Co-authors: Jirsová, A. – Macháčková, E. – Prouzová, H. – Svozilová, N.)
- Daneš et al. (1987)
  Daneš, F. – Grepl, M. – Hlavsa, Z. (ed.) (1987): Mluvnice češtiny 3. Praha, Academia.
- Dowty (2000)
  Dowty, D. (2000): ‘The Garden Swarms with Bees' and the Fallacy of ‘Argument Alternation'. In Yael, R. – Leacock, C. (ed.) Polysemy: Theoretical and Computational Approaches, s. 111–128. Oxford, Oxford University Press.
- Fried (2005)
  Fried, M. (2005): A frame-based approach to case alternations: The swarm-class verbs in Czech. Cognitive Linguistics. 16, s. 475–512.
- Giger (2003)
  Giger, M. (2003): Resultativa im modernen Tschechischen. Unter Berücksichtigung der Sprachgeschichte und der übrigen slavischen Sprachen. Bern – Berlin – Bruxelles – Frankfurt am Mein – New York – Oxford – Wien, Peter Lang.
- Grepl – Karlík (1998)
  Grepl, M. – Karlík, P. (1998): Skladba češtiny. Olomouc, Votobia.
- Hajičová (2007)
  Hajičová, E. (2007): Information Structure from the Point of View of the Relation of Function and Form. The Prague Bulletin of Mathematical Linguistics. 88, s. 53–72.
- Hirschová (1977)
  Hirschová, M. (1977): Vzájemné vztahy předpon a předložek ve vazbách s prostorovým významem (na materiálu českého jazyka). Slovo a slovesnost. 38, s. 103–111.
- Hopper – Thompson (1980)
  Hopper, P. J. – Thompson, S. A. (1980): Transitivity in Grammar and Discourse. Language. 56(2), s. 251–299.
- Hovav – Levin (1988)
  Hovav, M. R. – Levin, B. (1988): What to do with Θ-Roles. In Wilkins, W. (ed.) Syntax and Semantics, 21, s. 7–36. San Diego, Academic Press.
- Karlík et al. (2002)
  Karlík, P. – Nekula, M. – Pleskalová, J. (ed.) (2002): Encyklopedický slovník češtiny. Praha, Nakladatelství Lidové noviny.
- Kettnerová (2009)
  Kettnerová, V. (2009): Konstrukce s rozpadem tématu a dikta v češtině. Slovo a slovesnost. 70, s. 163–174.
- Kettnerová (2014)
  Kettnerová, V. (2014): Lexikálně-sémantické konverze ve valenčním slovníku. Praha, Karolinum.
- Kettnerová et al. (2015)
  Kettnerová, V. – Lopatková, M. – Panevová, J. (2015): Shoda doplňku v reflexivních konstrukcích v češtině. Slovo a slovesnost. 76(3), s. 198–214.
- Komárek et al. (1986)
  Komárek, M. et al. (ed.) (1986): Mluvnice češtiny 2. Praha, Academia. (Co-authors: Kořenský, J. – Petr, J. – Veselková, J.)
- Konečná (1966)
  Konečná, D. (1966): K otázce druhů objektu podle významu. Slavica Pragensia. 8, s. 311–316.
- Lopatková – Panevová (2007)
  Lopatková, M. – Panevová, J. (2007): Valence vybraných sloves pohybu v češtině. Zbornik Matice srpske za slavistiku. 71–72, s. 101–115.
- Oliva (2001)
  Oliva, K. (2001): Reflexe reflexivity reflexiv.: Slovo a slovesnost. 62(3), s. 200–207.
- Pajas (2005)
  Pajas, P. (2005): Kontroly valence v PDT.: Prezentace na semináři Ústavu formální a aplikované lingvistiky. (Dostupná z https://wiki.ufal.ms.mff.cuni.cz/_media/28-11-05-pajas-vallex.pdf.)
- Panevová (1999)
  Panevová, J. (1999): Česká reciproční zájmena a slovesná valence. Slovo a slovesnost. 60(4), s. 269–275.
- Panevová (2007)
  Panevová, J. (2007): Znovu o reciprocitě.: Slovo a slovesnost. 68(2), s. 91–100.
- Panevová (2008)
  Panevová, J. (2008): České konstrukce tzv. slovanského akuzativu s infinitivem. Slovo a slovesnost. 69(3), s. 163–175.
- Panevová et al. (2014)
  Panevová, J. et al. (2014): Mluvnice současné češtiny 2, Syntax na základě anotovaného korpusu. Praha, Karolinum. (Co-authors: Hajičová, E. – Kettnerová, V. – Lopatková, M. – Mikulová, M. – Ševčíková, M.)
- Panevová – Mikulová (2007)
  Panevová, J. – Mikulová, M. (2007): On Reciprocity. The Prague Bulletin of Mathematical Linguistics. 87, s. 27–40.
- Pinker (1989)
  Pinker, S. (1989): Learnability and Cognition. The Acquisition of Argument Structure. Cambridge, Massachusetts, London, MIT Press.
- Piťha (1992)
  Piťha, P. (1992): Posesivní vztah v češtině.: Praha, AVED.
- Razímová (2004)
  Razímová, M. (2004): Funkce adverbálního dativu v hloubkové a povrchové stavbě české věty. Diplomová práce, Praha, Univerzita Karlova v Praze, Filozofická fakulta.
- Rosen (2014)
  Rosen, A. (2014): Haplology of Reflexive Clitics in Czech.: In Kaczmarska, E. – Nomachi, M. (ed.) Slavic and German in Contact: Studies from Areal and Contrastive Linguistics, 26 / Slavic Eurasian Studies, s. 97–116. Sapporo, Slavic Research Center.
- Šmilauer (1966)
  Šmilauer, V. (1966): Novočeská skladba.: Praha, SPN.
- Urešová (2011)
  Urešová, Z. (2011): Valence sloves v Pražském závislostním korpusu. Praha, Ústav formální a aplikované lingvistiky.
- Urešová – Pajas (2009)
  Urešová, Z. – Pajas, P. (2009): Diatheses in the Czech Valency Lexicon PDT-Vallex. In Levická, J. – Garabík, R. (ed.) Proceedings of the Fifth International Conference Slovko 2009: NLP, Corpus Linguistics, Corpus Based Grammar Research, s. 358–376, Bratislava, Slovakia, Tribun.
- Wagner (2014)
  Wagner, R. (2014): A case of collision in principles of language description. The Prague Bulletin of Mathematical Linguistics. 101, s. 123–146.

## Obsah